@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,17 @@
 #include <string.h>
 #include <unistd.h>
 
+#include "compat_stdbool.h"
+#include "compat_stdint.h"
+#include "compat_inttypes.h"
+#include "compat_limits.h"
+#include "compat_unistd.h"
+#include "basedef.h"
+
 #include "attribute.h"
 #include "collection.h"
 #include "cvsync.h"
+#include "cvsync_attr.h"
 #include "filetypes.h"
 #include "list.h"
 #include "mdirent.h"
@@ -48,21 +56,21 @@
 #include "dircmp.h"
 #include "filescan.h"
 
-boolean dircmp_rcs_fetch(struct dircmp_args *);
+bool dircmp_rcs_fetch(struct dircmp_args *);
 
-boolean dircmp_rcs_add(struct dircmp_args *, struct mdirent_rcs *);
-boolean dircmp_rcs_add_dir(struct dircmp_args *, struct mdirent_rcs *);
-boolean dircmp_rcs_add_file(struct dircmp_args *, struct mdirent_rcs *);
-boolean dircmp_rcs_add_symlink(struct dircmp_args *, struct mdirent_rcs *);
-boolean dircmp_rcs_remove(struct dircmp_args *);
-boolean dircmp_rcs_remove_dir(struct dircmp_args *);
-boolean dircmp_rcs_remove_file(struct dircmp_args *);
-boolean dircmp_rcs_replace(struct dircmp_args *, struct mdirent_rcs *);
-boolean dircmp_rcs_update(struct dircmp_args *, struct mdirent_rcs *);
+bool dircmp_rcs_add(struct dircmp_args *, struct mdirent_rcs *);
+bool dircmp_rcs_add_dir(struct dircmp_args *, struct mdirent_rcs *);
+bool dircmp_rcs_add_file(struct dircmp_args *, struct mdirent_rcs *);
+bool dircmp_rcs_add_symlink(struct dircmp_args *, struct mdirent_rcs *);
+bool dircmp_rcs_remove(struct dircmp_args *);
+bool dircmp_rcs_remove_dir(struct dircmp_args *);
+bool dircmp_rcs_remove_file(struct dircmp_args *);
+bool dircmp_rcs_replace(struct dircmp_args *, struct mdirent_rcs *);
+bool dircmp_rcs_update(struct dircmp_args *, struct mdirent_rcs *);
 
 struct mDIR *dircmp_rcs_opendir(struct dircmp_args *, size_t);
 
-boolean
+bool
 dircmp_rcs(struct dircmp_args *dca)
 {
 	struct mDIR *mdirp;
@@ -70,31 +78,31 @@ dircmp_rcs(struct dircmp_args *dca)
 	struct cvsync_attr *cap = &dca->dca_attr;
 	struct list *lp;
 	int rv;
-	boolean fetched;
+	bool fetched;
 
 	if (dca->dca_collection->cl_scanfile != NULL)
 		return (dircmp_rcs_scanfile(dca));
 
 	if ((lp = list_init()) == NULL)
-		return (FALSE);
+		return (false);
 	list_set_destructor(lp, mclosedir);
 
 	if ((mdirp = dircmp_rcs_opendir(dca, dca->dca_pathlen)) == NULL) {
 		list_destroy(lp);
-		return (FALSE);
+		return (false);
 	}
 	mdirp->m_parent_pathlen = dca->dca_pathlen;
 
-	fetched = FALSE;
+	fetched = false;
 
 	for (;;) {
 		if (!fetched) {
 			if (!dircmp_rcs_fetch(dca)) {
 				mclosedir(mdirp);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
-			fetched = TRUE;
+			fetched = true;
 		}
 
 		if (cap->ca_tag == DIRCMP_END)
@@ -109,7 +117,7 @@ dircmp_rcs(struct dircmp_args *dca)
 				if (!dircmp_rcs_add(dca, mdp)) {
 					mclosedir(mdirp);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 			}
 			dca->dca_pathlen = mdirp->m_parent_pathlen;
@@ -118,11 +126,11 @@ dircmp_rcs(struct dircmp_args *dca)
 
 			if ((mdirp = list_remove_tail(lp)) == NULL) {
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 			mdirp->m_offset++;
 
-			fetched = FALSE;
+			fetched = false;
 			continue;
 		}
 
@@ -130,10 +138,10 @@ dircmp_rcs(struct dircmp_args *dca)
 			if (!dircmp_rcs_remove(dca)) {
 				mclosedir(mdirp);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 
-			fetched = FALSE;
+			fetched = false;
 			continue;
 		}
 
@@ -166,7 +174,7 @@ dircmp_rcs(struct dircmp_args *dca)
 			if (!dircmp_rcs_update(dca, mdp)) {
 				mclosedir(mdirp);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 			if (cap->ca_tag != DIRCMP_DOWN) {
 				mdirp->m_offset++;
@@ -176,13 +184,13 @@ dircmp_rcs(struct dircmp_args *dca)
 				if (!list_insert_tail(lp, mdirp)) {
 					mclosedir(mdirp);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 
 				len = dca->dca_pathlen + mdp->md_namelen + 1;
 				if (len >= dca->dca_pathmax) {
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				memcpy(&dca->dca_path[dca->dca_pathlen],
 				       mdp->md_name, mdp->md_namelen);
@@ -192,26 +200,26 @@ dircmp_rcs(struct dircmp_args *dca)
 				mdirp = dircmp_rcs_opendir(dca, len);
 				if (mdirp == NULL) {
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				mdirp->m_parent_pathlen = dca->dca_pathlen;
 				dca->dca_pathlen = len;
 			}
-			fetched = FALSE;
+			fetched = false;
 		} else if (rv < 0) {
 			if (!dircmp_rcs_add(dca, mdp)) {
 				mclosedir(mdirp);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 			mdirp->m_offset++;
 		} else { /* rv > 0 */
 			if (!dircmp_rcs_remove(dca)) {
 				mclosedir(mdirp);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
-			fetched = FALSE;
+			fetched = false;
 		}
 	}
 
@@ -225,7 +233,7 @@ dircmp_rcs(struct dircmp_args *dca)
 			if (!dircmp_rcs_add(dca, mdp)) {
 				mclosedir(mdirp);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 		}
 		mclosedir(mdirp);
@@ -235,16 +243,16 @@ dircmp_rcs(struct dircmp_args *dca)
 
 		if ((mdirp = list_remove_tail(lp)) == NULL) {
 			list_destroy(lp);
-			return (FALSE);
+			return (false);
 		}
 	}
 
 	list_destroy(lp);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_fetch(struct dircmp_args *dca)
 {
 	struct cvsync_attr *cap = &dca->dca_attr;
@@ -252,10 +260,10 @@ dircmp_rcs_fetch(struct dircmp_args *dca)
 	size_t len;
 
 	if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 3))
-		return (FALSE);
+		return (false);
 	len = GetWord(cmd);
 	if ((len == 0) || (len > dca->dca_cmdmax - 2))
-		return (FALSE);
+		return (false);
 	if ((cap->ca_tag = cmd[2]) == DIRCMP_END)
 		return (len == 1);
 	if (cap->ca_tag == DIRCMP_UP) {
@@ -263,54 +271,56 @@ dircmp_rcs_fetch(struct dircmp_args *dca)
 		return (len == 1);
 	}
 	if (len < 2)
-		return (FALSE);
+		return (false);
+
+	if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
+		return (false);
+	cap->ca_namelen = cmd[0];
 
 	switch (cap->ca_tag) {
 	case DIRCMP_DOWN:
 		cap->ca_type = FILETYPE_DIR;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
-			return (FALSE);
-		if ((cap->ca_namelen = cmd[0]) != len - RCS_ATTRLEN_DIR - 2)
-			return (FALSE);
-		if (cap->ca_namelen > sizeof(cap->ca_name))
-			return (FALSE);
+		if ((cap->ca_namelen == 0) ||
+		    (cap->ca_namelen > sizeof(cap->ca_name)) ||
+		    (cap->ca_namelen != len - RCS_ATTRLEN_DIR - 2)) {
+			return (false);
+		}
 		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_name,
 			      cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!cvsync_rcs_filename((char *)cap->ca_name,
 					 cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd,
 			      RCS_ATTRLEN_DIR)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!attr_rcs_decode_dir(cmd, RCS_ATTRLEN_DIR, cap))
-			return (FALSE);
+			return (false);
 		break;
 	case DIRCMP_FILE:
 		cap->ca_type = FILETYPE_FILE;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
-			return (FALSE);
-		if ((cap->ca_namelen = cmd[0]) != len - RCS_ATTRLEN_FILE - 2)
-			return (FALSE);
-		if (cap->ca_namelen > sizeof(cap->ca_name))
-			return (FALSE);
+		if ((cap->ca_namelen == 0) ||
+		    (cap->ca_namelen > sizeof(cap->ca_name)) ||
+		    (cap->ca_namelen != len - RCS_ATTRLEN_FILE - 2)) {
+			return (false);
+		}
 		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_name,
 			      cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!cvsync_rcs_filename((char *)cap->ca_name,
 					 cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd,
 			      RCS_ATTRLEN_FILE)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!attr_rcs_decode_file(cmd, RCS_ATTRLEN_FILE, cap))
-			return (FALSE);
+			return (false);
 		break;
 	case DIRCMP_RCS:
 	case DIRCMP_RCS_ATTIC:
@@ -318,59 +328,58 @@ dircmp_rcs_fetch(struct dircmp_args *dca)
 			cap->ca_type = FILETYPE_RCS;
 		else
 			cap->ca_type = FILETYPE_RCS_ATTIC;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
-			return (FALSE);
-		if ((cap->ca_namelen = cmd[0]) != len - RCS_ATTRLEN_RCS - 2)
-			return (FALSE);
-		if (cap->ca_namelen > sizeof(cap->ca_name))
-			return (FALSE);
+		if ((cap->ca_namelen == 0) ||
+		    (cap->ca_namelen > sizeof(cap->ca_name)) ||
+		    (cap->ca_namelen != len - RCS_ATTRLEN_RCS - 2)) {
+			return (false);
+		}
 		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_name,
 			      cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!cvsync_rcs_filename((char *)cap->ca_name,
 					 cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd,
 			      RCS_ATTRLEN_RCS)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!attr_rcs_decode_rcs(cmd, RCS_ATTRLEN_RCS, cap))
-			return (FALSE);
+			return (false);
 		break;
 	case DIRCMP_SYMLINK:
 		cap->ca_type = FILETYPE_SYMLINK;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
-			return (FALSE);
-		if ((cap->ca_namelen = cmd[0]) > sizeof(cap->ca_name))
-			return (FALSE);
+		if ((cap->ca_namelen == 0) ||
+		    (cap->ca_namelen > sizeof(cap->ca_name))) {
+			return (false);
+		}
 		if (len <= cap->ca_namelen + 2)
-			return (FALSE);
+			return (false);
 		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_name,
 			      cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!cvsync_rcs_filename((char *)cap->ca_name,
 					 cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		cap->ca_auxlen = len - cap->ca_namelen - 2;
 		if (cap->ca_auxlen > sizeof(cap->ca_aux))
-			return (FALSE);
+			return (false);
 		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_aux,
 			      cap->ca_auxlen)) {
-			return (FALSE);
+			return (false);
 		}
 		break;
 	default:
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 {
 	struct mDIR *mdirp;
@@ -385,17 +394,17 @@ dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 		return (dircmp_rcs_add_symlink(dca, mdp));
 
 	if (!S_ISDIR(st->st_mode))
-		return (FALSE);
+		return (false);
 	if (!dircmp_rcs_add_dir(dca, mdp))
-		return (FALSE);
+		return (false);
 
 	if ((lp = list_init()) == NULL)
-		return (FALSE);
+		return (false);
 	list_set_destructor(lp, mclosedir);
 
 	len = dca->dca_pathlen + mdp->md_namelen + 1;
 	if (len >= dca->dca_pathmax)
-		return (FALSE);
+		return (false);
 
 	memcpy(&dca->dca_path[dca->dca_pathlen], mdp->md_name,
 	       mdp->md_namelen);
@@ -404,7 +413,7 @@ dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 
 	if ((mdirp = dircmp_rcs_opendir(dca, len)) == NULL) {
 		list_destroy(lp);
-		return (FALSE);
+		return (false);
 	}
 	mdirp->m_parent_pathlen = dca->dca_pathlen;
 	dca->dca_pathlen = len;
@@ -412,13 +421,13 @@ dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 	if (!list_insert_tail(lp, mdirp)) {
 		mclosedir(mdirp);
 		list_destroy(lp);
-		return (FALSE);
+		return (false);
 	}
 
 	do {
 		if ((mdirp = list_remove_tail(lp)) == NULL) {
 			list_destroy(lp);
-			return (FALSE);
+			return (false);
 		}
 
 		while (mdirp->m_offset < mdirp->m_nentries) {
@@ -432,14 +441,14 @@ dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 				if (!dircmp_rcs_add_dir(dca, mdp)) {
 					mclosedir(mdirp);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 
 				len = dca->dca_pathlen + mdp->md_namelen + 1;
 				if (len >= dca->dca_pathmax) {
 					mclosedir(mdirp);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				memcpy(&dca->dca_path[dca->dca_pathlen],
 				       mdp->md_name, mdp->md_namelen);
@@ -449,13 +458,13 @@ dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 				if (!list_insert_tail(lp, mdirp)) {
 					mclosedir(mdirp);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 
 				mdirp = dircmp_rcs_opendir(dca, len);
 				if (mdirp == NULL) {
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				mdirp->m_parent_pathlen = dca->dca_pathlen;
 				dca->dca_pathlen = len;
@@ -465,20 +474,20 @@ dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 				if (!dircmp_rcs_add_file(dca, mdp)) {
 					mclosedir(mdirp);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				break;
 			case S_IFLNK:
 				if (!dircmp_rcs_add_symlink(dca, mdp)) {
 					mclosedir(mdirp);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				break;
 			default:
 				mclosedir(mdirp);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 		}
 
@@ -490,48 +499,48 @@ dircmp_rcs_add(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 
 	list_destroy(lp);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_add_dir(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 {
 	uint8_t *cmd = dca->dca_cmd;
 	size_t len, rlen;
 
 	if ((len = dca->dca_pathlen + mdp->md_namelen) >= dca->dca_pathmax)
-		return (FALSE);
+		return (false);
 	rlen = dca->dca_pathlen - dca->dca_rpathlen;
 	if ((len = rlen + mdp->md_namelen + 6) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILESCAN_ADD;
 	cmd[3] = FILETYPE_DIR;
 	SetWord(&cmd[4], rlen + mdp->md_namelen);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, dca->dca_rpath, rlen))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, mdp->md_name,
 		      mdp->md_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_add_file(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 {
 	uint8_t *cmd = dca->dca_cmd;
 	size_t len, rlen;
 
 	if ((len = dca->dca_pathlen + mdp->md_namelen) >= dca->dca_pathmax)
-		return (FALSE);
+		return (false);
 	rlen = dca->dca_pathlen - dca->dca_rpathlen;
 	if ((len = rlen + mdp->md_namelen + 6) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	if (IS_FILE_RCS(mdp->md_name, mdp->md_namelen)) {
 		if (mdp->md_attic)
@@ -546,46 +555,46 @@ dircmp_rcs_add_file(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 	cmd[2] = FILESCAN_ADD;
 	SetWord(&cmd[4], rlen + mdp->md_namelen);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, dca->dca_rpath, rlen))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, mdp->md_name,
 		      mdp->md_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_add_symlink(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 {
 	uint8_t *cmd = dca->dca_cmd;
 	size_t len, rlen;
 
 	if ((len = dca->dca_pathlen + mdp->md_namelen) >= dca->dca_pathmax)
-		return (FALSE);
+		return (false);
 	rlen = dca->dca_pathlen - dca->dca_rpathlen;
 	if ((len = rlen + mdp->md_namelen + 6) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILESCAN_ADD;
 	cmd[3] = FILETYPE_SYMLINK;
 	SetWord(&cmd[4], rlen + mdp->md_namelen);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, dca->dca_rpath, rlen))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, mdp->md_name,
 		      mdp->md_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_remove(struct dircmp_args *dca)
 {
 	struct cvsync_attr *cap = &dca->dca_attr;
@@ -596,14 +605,14 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 
 	n = 4;
 	if ((plen_stack = malloc(n * sizeof(*plen_stack))) == NULL)
-		return (FALSE);
+		return (false);
 	plen_stack[0] = dca->dca_pathlen;
 	c = 1;
 
 	len = dca->dca_pathlen + cap->ca_namelen + 1;
 	if (len >= dca->dca_pathmax) {
 		free(plen_stack);
-		return (FALSE);
+		return (false);
 	}
 
 	memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
@@ -615,13 +624,13 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 	do {
 		if (!dircmp_rcs_fetch(dca)) {
 			free(plen_stack);
-			return (FALSE);
+			return (false);
 		}
 
 		switch (cap->ca_tag) {
 		case DIRCMP_END:
 			free(plen_stack);
-			return (FALSE);
+			return (false);
 		case DIRCMP_DOWN:
 			if (c == n) {
 				size_t *newp, old = n, new = old * 2;
@@ -629,7 +638,7 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 				newp = malloc(new * sizeof(*newp));
 				if (newp == NULL) {
 					free(plen_stack);
-					return (FALSE);
+					return (false);
 				}
 				memcpy(newp, plen_stack, old * sizeof(*newp));
 				memset(&newp[old], 0,
@@ -644,7 +653,7 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 			len = dca->dca_pathlen + cap->ca_namelen + 1;
 			if (len >= dca->dca_pathmax) {
 				free(plen_stack);
-				return (FALSE);
+				return (false);
 			}
 
 			memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
@@ -659,7 +668,7 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 
 			if (!dircmp_rcs_remove_dir(dca)) {
 				free(plen_stack);
-				return (FALSE);
+				return (false);
 			}
 
 			dca->dca_pathlen = plen_stack[--c];
@@ -672,20 +681,20 @@ dircmp_rcs_remove(struct dircmp_args *dca)
 		case DIRCMP_SYMLINK:
 			if (!dircmp_rcs_remove_file(dca)) {
 				free(plen_stack);
-				return (FALSE);
+				return (false);
 			}
 			break;
 		default:
-			return (FALSE);
+			return (false);
 		}
 	} while (c > 0);
 
 	free(plen_stack);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_remove_dir(struct dircmp_args *dca)
 {
 	uint8_t *cmd = dca->dca_cmd;
@@ -693,21 +702,21 @@ dircmp_rcs_remove_dir(struct dircmp_args *dca)
 
 	rlen = dca->dca_pathlen - dca->dca_rpathlen - 1;
 	if ((len = rlen + 6) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILESCAN_REMOVE;
 	cmd[3] = FILETYPE_DIR;
 	SetWord(&cmd[4], rlen);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, dca->dca_rpath, rlen))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_remove_file(struct dircmp_args *dca)
 {
 	struct cvsync_attr *cap = &dca->dca_attr;
@@ -715,28 +724,28 @@ dircmp_rcs_remove_file(struct dircmp_args *dca)
 	size_t len, rlen;
 
 	if ((len = dca->dca_pathlen + cap->ca_namelen) >= dca->dca_pathmax)
-		return (FALSE);
+		return (false);
 	rlen = dca->dca_pathlen - dca->dca_rpathlen;
 	if ((len = rlen + cap->ca_namelen + 6) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILESCAN_REMOVE;
 	cmd[3] = cap->ca_type;
 	SetWord(&cmd[4], rlen + cap->ca_namelen);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, dca->dca_rpath, rlen))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cap->ca_name,
 		      cap->ca_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_replace(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 {
 	switch (mdp->md_stat.st_mode & S_IFMT) {
@@ -744,18 +753,18 @@ dircmp_rcs_replace(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 	case S_IFREG:
 	case S_IFLNK:
 		if (!dircmp_rcs_remove(dca))
-			return (FALSE);
+			return (false);
 		if (!dircmp_rcs_add(dca, mdp))
-			return (FALSE);
+			return (false);
 		break;
 	default:
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_update(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 {
 	struct cvsync_attr *cap = &dca->dca_attr;
@@ -766,10 +775,10 @@ dircmp_rcs_update(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 	int wn;
 
 	if ((len = dca->dca_pathlen + mdp->md_namelen) >= dca->dca_pathmax)
-		return (FALSE);
+		return (false);
 	rlen = dca->dca_pathlen - dca->dca_rpathlen;
 	if ((base = rlen + mdp->md_namelen + 6) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	len = dca->dca_cmdmax - base;
 
@@ -778,11 +787,11 @@ dircmp_rcs_update(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 		if (cap->ca_type != FILETYPE_DIR)
 			return (dircmp_rcs_replace(dca, mdp));
 		if (mode == cap->ca_mode)
-			return (TRUE);
+			return (true);
 		cmd[2] = FILESCAN_SETATTR;
 		cmd[3] = FILETYPE_DIR;
 		if ((len = attr_rcs_encode_dir(&cmd[6], len, mode)) == 0)
-			return (FALSE);
+			return (false);
 		break;
 	case S_IFREG:
 		if (IS_FILE_RCS(mdp->md_name, mdp->md_namelen)) {
@@ -797,7 +806,7 @@ dircmp_rcs_update(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 			if ((cmd[3] == cap->ca_type) &&
 			    ((int64_t)st->st_mtime == cap->ca_mtime) &&
 			    (mode == cap->ca_mode)) {
-				return (TRUE);
+				return (true);
 			}
 			if (cap->ca_type != cmd[3]) {
 				cmd[2] = FILESCAN_RCS_ATTIC;
@@ -810,7 +819,7 @@ dircmp_rcs_update(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 			if ((len = attr_rcs_encode_rcs(&cmd[6], len,
 						       st->st_mtime,
 						       mode)) == 0) {
-				return (FALSE);
+				return (false);
 			}
 		} else {
 			if (cap->ca_type != FILETYPE_FILE)
@@ -818,7 +827,7 @@ dircmp_rcs_update(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 			if (((int64_t)st->st_mtime == cap->ca_mtime) &&
 			    ((uint64_t)st->st_size == cap->ca_size) &&
 			    (mode == cap->ca_mode)) {
-				return (TRUE);
+				return (true);
 			}
 			if (((int64_t)st->st_mtime != cap->ca_mtime) ||
 			    ((uint64_t)st->st_size != cap->ca_size)) {
@@ -834,7 +843,7 @@ dircmp_rcs_update(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 							st->st_mtime,
 							st->st_size,
 							mode)) == 0) {
-				return (FALSE);
+				return (false);
 			}
 		}
 		break;
@@ -846,37 +855,37 @@ dircmp_rcs_update(struct dircmp_args *dca, struct mdirent_rcs *mdp)
 		dca->dca_path[dca->dca_pathlen + mdp->md_namelen] = '\0';
 		if ((wn = readlink(dca->dca_path, dca->dca_symlink,
 				   dca->dca_pathmax)) == -1) {
-			return (FALSE);
+			return (false);
 		}
 		len = (size_t)wn;
 		if ((len == cap->ca_auxlen) &&
 		    (memcmp(cap->ca_aux, dca->dca_symlink, len) == 0)) {
-			return (TRUE);
+			return (true);
 		}
 		cmd[2] = FILESCAN_UPDATE;
 		cmd[3] = FILETYPE_SYMLINK;
 		len = 0;
 		break;
 	default:
-		return (FALSE);
+		return (false);
 	}
 
 	SetWord(cmd, len + base - 2);
 	SetWord(&cmd[4], rlen + mdp->md_namelen);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, dca->dca_rpath, rlen))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, mdp->md_name,
 		      mdp->md_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 	if (len > 0) {
 		if (!mux_send(dca->dca_mux, MUX_FILESCAN, &cmd[6], len))
-			return (FALSE);
+			return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
 struct mDIR *
@@ -891,7 +900,7 @@ dircmp_rcs_opendir(struct dircmp_args *dca, size_t pathlen)
 
 	mda.mda_errormode = cl->cl_errormode;
 	mda.mda_symfollow = cl->cl_symfollow;
-	mda.mda_remove = FALSE;
+	mda.mda_remove = false;
 
 	if (rpathlen >= cl->cl_rprefixlen) {
 		if ((mdirp = mopendir_rcs(dca->dca_path, pathlen,
@@ -915,8 +924,8 @@ dircmp_rcs_opendir(struct dircmp_args *dca, size_t pathlen)
 	}
 	memcpy(mdp->md_name, &cl->cl_rprefix[rpathlen], len);
 	mdp->md_namelen = len;
-	mdp->md_attic = FALSE;
-	mdp->md_dead = FALSE;
+	mdp->md_attic = false;
+	mdp->md_dead = false;
 
 	len = cl->cl_prefixlen + rpathlen + mdp->md_namelen;
 	if (len >= dca->dca_pathmax) {
