@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,15 +27,25 @@
  * SUCH DAMAGE.
  */
 
+#include <sys/types.h>
+#include <sys/stat.h>
+
 #include <stdlib.h>
 
 #include <limits.h>
 #include <pthread.h>
 #include <string.h>
 
+#include "compat_stdbool.h"
+#include "compat_stdint.h"
+#include "compat_inttypes.h"
+#include "compat_limits.h"
+#include "basedef.h"
+
 #include "attribute.h"
 #include "collection.h"
 #include "cvsync.h"
+#include "cvsync_attr.h"
 #include "filetypes.h"
 #include "list.h"
 #include "mux.h"
@@ -44,23 +54,19 @@
 #include "dircmp.h"
 #include "filescan.h"
 
-boolean dircmp_rcs_scanfile_add(struct dircmp_args *, struct scanfile_attr *);
-boolean dircmp_rcs_scanfile_add_file(struct dircmp_args *,
-				     struct scanfile_attr *);
-boolean dircmp_rcs_scanfile_remove(struct dircmp_args *,
-				   struct scanfile_attr *);
-boolean dircmp_rcs_scanfile_remove_dir(struct dircmp_args *);
-boolean dircmp_rcs_scanfile_remove_file(struct dircmp_args *);
-boolean dircmp_rcs_scanfile_replace(struct dircmp_args *,
-				    struct scanfile_attr *);
-boolean dircmp_rcs_scanfile_update(struct dircmp_args *,
-				   struct scanfile_attr *);
+bool dircmp_rcs_scanfile_add(struct dircmp_args *, struct scanfile_attr *);
+bool dircmp_rcs_scanfile_add_file(struct dircmp_args *, struct scanfile_attr *);
+bool dircmp_rcs_scanfile_remove(struct dircmp_args *, struct scanfile_attr *);
+bool dircmp_rcs_scanfile_remove_dir(struct dircmp_args *);
+bool dircmp_rcs_scanfile_remove_file(struct dircmp_args *);
+bool dircmp_rcs_scanfile_replace(struct dircmp_args *, struct scanfile_attr *);
+bool dircmp_rcs_scanfile_update(struct dircmp_args *, struct scanfile_attr *);
 
-boolean dircmp_rcs_scanfile_fetch(struct dircmp_args *);
-boolean dircmp_rcs_scanfile_read(struct dircmp_args *, struct scanfile_attr *);
-boolean dircmp_isparent(struct scanfile_attr *, struct scanfile_attr *);
+bool dircmp_rcs_scanfile_fetch(struct dircmp_args *);
+bool dircmp_rcs_scanfile_read(struct dircmp_args *, struct scanfile_attr *);
+bool dircmp_isparent(struct scanfile_attr *, struct scanfile_attr *);
 
-boolean
+bool
 dircmp_rcs_scanfile(struct dircmp_args *dca)
 {
 	struct cvsync_attr *cap = &dca->dca_attr;
@@ -71,10 +77,10 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 	const uint8_t *name, *sv_name;
 	size_t namelen;
 	int rv;
-	boolean fetched = FALSE;
+	bool fetched = false;
 
 	if ((lp = list_init()) == NULL)
-		return (FALSE);
+		return (false);
 	list_set_destructor(lp, free);
 
 	dirattr = NULL;
@@ -84,7 +90,7 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 	} else {
 		if (sa->sa_start != sa->sa_end) {
 			list_destroy(lp);
-			return (FALSE);
+			return (false);
 		}
 		attr = NULL;
 	}
@@ -95,9 +101,9 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 				if (dirattr != NULL)
 					free(dirattr);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
-			fetched = TRUE;
+			fetched = true;
 		}
 
 		if (cap->ca_tag == DIRCMP_END)
@@ -106,7 +112,7 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 		if (cap->ca_tag == DIRCMP_UP) {
 			if (dirattr == NULL) {
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 
 			if (attr != NULL) {
@@ -115,7 +121,7 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 								     attr)) {
 						free(dirattr);
 						list_destroy(lp);
-						return (FALSE);
+						return (false);
 					}
 					if (dircmp_rcs_scanfile_read(dca,
 								     attr)) {
@@ -125,7 +131,7 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 					if (sa->sa_start != sa->sa_end) {
 						free(dirattr);
 						list_destroy(lp);
-						return (FALSE);
+						return (false);
 					}
 					attr = NULL;
 					break;
@@ -139,10 +145,10 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 			} else {
 				if ((dirattr = list_remove_tail(lp)) == NULL) {
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 			}
-			fetched = FALSE;
+			fetched = false;
 			continue;
 		}
 
@@ -151,9 +157,9 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 				if (dirattr != NULL)
 					free(dirattr);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
-			fetched = FALSE;
+			fetched = false;
 			continue;
 		}
 
@@ -189,20 +195,20 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 				if (dirattr != NULL)
 					free(dirattr);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 			if (cap->ca_tag == DIRCMP_DOWN) {
 				if ((dirattr != NULL) &&
 				    !list_insert_tail(lp, dirattr)) {
 					free(dirattr);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 
 				dirattr = cvsync_memdup(attr, sizeof(*attr));
 				if (dirattr == NULL) {
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 
 				if (dircmp_rcs_scanfile_read(dca, attr)) {
@@ -211,7 +217,7 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 					if (sa->sa_start != sa->sa_end) {
 						free(dirattr);
 						list_destroy(lp);
-						return (FALSE);
+						return (false);
 					}
 					attr = NULL;
 				}
@@ -222,18 +228,18 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 					if (sa->sa_start != sa->sa_end) {
 						free(dirattr);
 						list_destroy(lp);
-						return (FALSE);
+						return (false);
 					}
 					attr = NULL;
 				}
 			}
-			fetched = FALSE;
+			fetched = false;
 		} else if (rv < 0) {
 			if (!dircmp_rcs_scanfile_add(dca, attr)) {
 				if (dirattr != NULL)
 					free(dirattr);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 			if (dircmp_rcs_scanfile_read(dca, attr)) {
 				sa->sa_start += attr->a_size;
@@ -242,7 +248,7 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 					if (dirattr != NULL)
 						free(dirattr);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				attr = NULL;
 			}
@@ -251,16 +257,16 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 				if (dirattr != NULL)
 					free(dirattr);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
-			fetched = FALSE;
+			fetched = false;
 		}
 	}
 
 	if (attr != NULL) {
 		if (!dircmp_rcs_scanfile_add(dca, attr)) {
 			list_destroy(lp);
-			return (FALSE);
+			return (false);
 		}
 	} else {
 		attr = &sa->sa_attr;
@@ -268,22 +274,22 @@ dircmp_rcs_scanfile(struct dircmp_args *dca)
 	while (sa->sa_start < sa->sa_end) {
 		if (!dircmp_rcs_scanfile_read(dca, attr)) {
 			list_destroy(lp);
-			return (FALSE);
+			return (false);
 		}
 		sa->sa_start += attr->a_size;
 
 		if (!dircmp_rcs_scanfile_add(dca, attr)) {
 			list_destroy(lp);
-			return (FALSE);
+			return (false);
 		}
 	}
 
 	list_destroy(lp);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_scanfile_fetch(struct dircmp_args *dca)
 {
 	struct cvsync_attr *cap = &dca->dca_attr;
@@ -291,10 +297,10 @@ dircmp_rcs_scanfile_fetch(struct dircmp_args *dca)
 	size_t len;
 
 	if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 3))
-		return (FALSE);
+		return (false);
 	len = GetWord(cmd);
 	if ((len == 0) || (len > dca->dca_cmdmax - 2))
-		return (FALSE);
+		return (false);
 	if ((cap->ca_tag = cmd[2]) == DIRCMP_END)
 		return (len == 1);
 	if (cap->ca_tag == DIRCMP_UP) {
@@ -302,49 +308,29 @@ dircmp_rcs_scanfile_fetch(struct dircmp_args *dca)
 		return (len == 1);
 	}
 	if (len < 2)
-		return (FALSE);
+		return (false);
+
+	if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
+		return (false);
+	cap->ca_namelen = cmd[0];
 
 	switch (cap->ca_tag) {
 	case DIRCMP_DOWN:
 		cap->ca_type = FILETYPE_DIR;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
-			return (FALSE);
-		if ((cap->ca_namelen = cmd[0]) != len - RCS_ATTRLEN_DIR - 2)
-			return (FALSE);
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_name,
-			      cap->ca_namelen)) {
-			return (FALSE);
-		}
-		if (!cvsync_rcs_filename((char *)cap->ca_name,
-					 cap->ca_namelen)) {
-			return (FALSE);
-		}
 		cap->ca_auxlen = RCS_ATTRLEN_DIR;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_aux,
-			      cap->ca_auxlen)) {
-			return (FALSE);
+		if ((cap->ca_namelen == 0) ||
+		    (cap->ca_namelen > sizeof(cap->ca_name)) ||
+		    (cap->ca_namelen != len - cap->ca_auxlen - 2)) {
+			return (false);
 		}
 		break;
 	case DIRCMP_FILE:
 		cap->ca_type = FILETYPE_FILE;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
-			return (FALSE);
-		if ((cap->ca_namelen = cmd[0]) != len - RCS_ATTRLEN_FILE - 2)
-			return (FALSE);
-		if (cap->ca_namelen > sizeof(cap->ca_name))
-			return (FALSE);
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_name,
-			      cap->ca_namelen)) {
-			return (FALSE);
-		}
-		if (!cvsync_rcs_filename((char *)cap->ca_name,
-					 cap->ca_namelen)) {
-			return (FALSE);
-		}
 		cap->ca_auxlen = RCS_ATTRLEN_FILE;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_aux,
-			      cap->ca_auxlen)) {
-			return (FALSE);
+		if ((cap->ca_namelen == 0) ||
+		    (cap->ca_namelen > sizeof(cap->ca_name)) ||
+		    (cap->ca_namelen != len - cap->ca_auxlen - 2)) {
+			return (false);
 		}
 		break;
 	case DIRCMP_RCS:
@@ -353,58 +339,44 @@ dircmp_rcs_scanfile_fetch(struct dircmp_args *dca)
 			cap->ca_type = FILETYPE_RCS;
 		else
 			cap->ca_type = FILETYPE_RCS_ATTIC;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
-			return (FALSE);
-		if ((cap->ca_namelen = cmd[0]) != len - RCS_ATTRLEN_RCS - 2)
-			return (FALSE);
-		if (cap->ca_namelen > sizeof(cap->ca_name))
-			return (FALSE);
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_name,
-			      cap->ca_namelen)) {
-			return (FALSE);
-		}
-		if (!cvsync_rcs_filename((char *)cap->ca_name,
-					 cap->ca_namelen)) {
-			return (FALSE);
-		}
 		cap->ca_auxlen = RCS_ATTRLEN_RCS;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_aux,
-			      cap->ca_auxlen)) {
-			return (FALSE);
+		if ((cap->ca_namelen == 0) ||
+		    (cap->ca_namelen > sizeof(cap->ca_name)) ||
+		    (cap->ca_namelen != len - cap->ca_auxlen - 2)) {
+			return (false);
 		}
 		break;
 	case DIRCMP_SYMLINK:
 		cap->ca_type = FILETYPE_SYMLINK;
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cmd, 1))
-			return (FALSE);
-		if ((cap->ca_namelen = cmd[0]) > sizeof(cap->ca_name))
-			return (FALSE);
+		if ((cap->ca_namelen == 0) ||
+		    (cap->ca_namelen > sizeof(cap->ca_name))) {
+			return (false);
+		}
 		if (len <= cap->ca_namelen + 2)
-			return (FALSE);
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_name,
-			      cap->ca_namelen)) {
-			return (FALSE);
-		}
-		if (!cvsync_rcs_filename((char *)cap->ca_name,
-					 cap->ca_namelen)) {
-			return (FALSE);
-		}
+			return (false);
 		cap->ca_auxlen = len - cap->ca_namelen - 2;
 		if (cap->ca_auxlen > sizeof(cap->ca_aux))
-			return (FALSE);
-		if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_aux,
-			      cap->ca_auxlen)) {
-			return (FALSE);
-		}
+			return (false);
 		break;
 	default:
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_name,
+		      cap->ca_namelen)) {
+		return (false);
+	}
+	if (!cvsync_rcs_filename((char *)cap->ca_name, cap->ca_namelen))
+		return (false);
+	if (!mux_recv(dca->dca_mux, MUX_DIRCMP_IN, cap->ca_aux,
+		      cap->ca_auxlen)) {
+		return (false);
+	}
+
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_scanfile_add(struct dircmp_args *dca, struct scanfile_attr *attr)
 {
 	struct scanfile_args *sa = dca->dca_collection->cl_scanfile;
@@ -412,24 +384,24 @@ dircmp_rcs_scanfile_add(struct dircmp_args *dca, struct scanfile_attr *attr)
 	struct list *lp;
 
 	if (!dircmp_rcs_scanfile_add_file(dca, attr))
-		return (FALSE);
+		return (false);
 
 	if (attr->a_type != FILETYPE_DIR)
-		return (TRUE);
+		return (true);
 
 	if ((lp = list_init()) == NULL)
-		return (FALSE);
+		return (false);
 	list_set_destructor(lp, free);
 
 	if ((dirattr = cvsync_memdup(attr, sizeof(*attr))) == NULL) {
 		list_destroy(lp);
-		return (FALSE);
+		return (false);
 	}
 
 	if (!list_insert_tail(lp, dirattr)) {
 		free(dirattr);
 		list_destroy(lp);
-		return (FALSE);
+		return (false);
 	}
 
 	if (dircmp_rcs_scanfile_read(dca, attr)) {
@@ -437,7 +409,7 @@ dircmp_rcs_scanfile_add(struct dircmp_args *dca, struct scanfile_attr *attr)
 	} else {
 		if (sa->sa_start != sa->sa_end) {
 			list_destroy(lp);
-			return (FALSE);
+			return (false);
 		}
 		attr = NULL;
 	}
@@ -445,7 +417,7 @@ dircmp_rcs_scanfile_add(struct dircmp_args *dca, struct scanfile_attr *attr)
 	do {
 		if ((dirattr = list_remove_tail(lp)) == NULL) {
 			list_destroy(lp);
-			return (FALSE);
+			return (false);
 		}
 
 		while ((attr != NULL) && dircmp_isparent(dirattr, attr)) {
@@ -454,16 +426,16 @@ dircmp_rcs_scanfile_add(struct dircmp_args *dca, struct scanfile_attr *attr)
 				if (!list_insert_tail(lp, dirattr)) {
 					free(dirattr);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				if (!dircmp_rcs_scanfile_add_file(dca, attr)) {
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				dirattr = cvsync_memdup(attr, sizeof(*attr));
 				if (dirattr == NULL) {
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				break;
 			case FILETYPE_FILE:
@@ -473,13 +445,13 @@ dircmp_rcs_scanfile_add(struct dircmp_args *dca, struct scanfile_attr *attr)
 				if (!dircmp_rcs_scanfile_add_file(dca, attr)) {
 					free(dirattr);
 					list_destroy(lp);
-					return (FALSE);
+					return (false);
 				}
 				break;
 			default:
 				free(dirattr);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 
 			if (!dircmp_rcs_scanfile_read(dca, attr)) {
@@ -489,7 +461,7 @@ dircmp_rcs_scanfile_add(struct dircmp_args *dca, struct scanfile_attr *attr)
 				}
 				free(dirattr);
 				list_destroy(lp);
-				return (FALSE);
+				return (false);
 			}
 			sa->sa_start += attr->a_size;
 		}
@@ -502,10 +474,10 @@ dircmp_rcs_scanfile_add(struct dircmp_args *dca, struct scanfile_attr *attr)
 
 	list_destroy(lp);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_scanfile_add_file(struct dircmp_args *dca,
 			     struct scanfile_attr *attr)
 {
@@ -513,23 +485,23 @@ dircmp_rcs_scanfile_add_file(struct dircmp_args *dca,
 	size_t len;
 
 	if ((len = attr->a_namelen + 6) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILESCAN_ADD;
 	cmd[3] = attr->a_type;
 	SetWord(&cmd[4], attr->a_namelen);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, attr->a_name,
 		      attr->a_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 {
 	struct cvsync_attr *cap = &dca->dca_attr;
@@ -538,7 +510,7 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 	if (attr != NULL) {
 		dca->dca_pathlen = attr->a_namelen + 1;
 		if (dca->dca_pathlen >= dca->dca_pathmax)
-			return (FALSE);
+			return (false);
 		memcpy(dca->dca_path, attr->a_name, attr->a_namelen);
 		dca->dca_path[attr->a_namelen] = '/';
 	} else {
@@ -550,12 +522,12 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 
 	n = 4;
 	if ((plen_stack = malloc(n * sizeof(*plen_stack))) == NULL)
-		return (FALSE);
+		return (false);
 	plen_stack[0] = dca->dca_pathlen;
 	c = 1;
 
 	if ((len =  dca->dca_pathlen + cap->ca_namelen + 1) >= dca->dca_pathmax)
-		return (FALSE);
+		return (false);
 	memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
 	       cap->ca_namelen);
 	dca->dca_path[dca->dca_pathlen + cap->ca_namelen] = '/';
@@ -564,13 +536,13 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 	do {
 		if (!dircmp_rcs_scanfile_fetch(dca)) {
 			free(plen_stack);
-			return (FALSE);
+			return (false);
 		}
 
 		switch (cap->ca_tag) {
 		case DIRCMP_END:
 			free(plen_stack);
-			return (FALSE);
+			return (false);
 		case DIRCMP_DOWN:
 			if (c == n) {
 				size_t *newp, old = n, new = old * 2;
@@ -578,7 +550,7 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 				newp = malloc(new * sizeof(*newp));
 				if (newp == NULL) {
 					free(plen_stack);
-					return (FALSE);
+					return (false);
 				}
 				memcpy(newp, plen_stack, old * sizeof(*newp));
 				memset(&newp[old], 0,
@@ -593,7 +565,7 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 			len = dca->dca_pathlen + cap->ca_namelen + 1;
 			if (len >= dca->dca_pathmax) {
 				free(plen_stack);
-				return (FALSE);
+				return (false);
 			}
 
 			memcpy(&dca->dca_path[dca->dca_pathlen], cap->ca_name,
@@ -605,7 +577,7 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 		case DIRCMP_UP:
 			if (!dircmp_rcs_scanfile_remove_dir(dca)) {
 				free(plen_stack);
-				return (FALSE);
+				return (false);
 			}
 
 			dca->dca_pathlen = plen_stack[--c];
@@ -617,43 +589,43 @@ dircmp_rcs_scanfile_remove(struct dircmp_args *dca, struct scanfile_attr *attr)
 		case DIRCMP_SYMLINK:
 			if (!dircmp_rcs_scanfile_remove_file(dca)) {
 				free(plen_stack);
-				return (FALSE);
+				return (false);
 			}
 			break;
 		default:
-			return (FALSE);
+			return (false);
 		}
 	} while (c > 0);
 
 	free(plen_stack);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_scanfile_remove_dir(struct dircmp_args *dca)
 {
 	uint8_t *cmd = dca->dca_cmd;
 	size_t len;
 
 	if ((len = dca->dca_pathlen + 5) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILESCAN_REMOVE;
 	cmd[3] = FILETYPE_DIR;
 	SetWord(&cmd[4], dca->dca_pathlen - 1);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, dca->dca_path,
 		      dca->dca_pathlen - 1)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_scanfile_remove_file(struct dircmp_args *dca)
 {
 	struct cvsync_attr *cap = &dca->dca_attr;
@@ -661,27 +633,27 @@ dircmp_rcs_scanfile_remove_file(struct dircmp_args *dca)
 	size_t len;
 
 	if ((len = dca->dca_pathlen + cap->ca_namelen + 6) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILESCAN_REMOVE;
 	cmd[3] = cap->ca_type;
 	SetWord(&cmd[4], dca->dca_pathlen + cap->ca_namelen);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, dca->dca_path,
 		      dca->dca_pathlen)) {
-		return (FALSE);
+		return (false);
 	}
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cap->ca_name,
 		      cap->ca_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_scanfile_replace(struct dircmp_args *dca,
 			    struct scanfile_attr *attr)
 {
@@ -703,24 +675,24 @@ dircmp_rcs_scanfile_replace(struct dircmp_args *dca,
 		}
 		break;
 	default:
-		return (FALSE);
+		return (false);
 	}
 
 	if (attr->a_namelen == 0) {
 		if (!dircmp_rcs_scanfile_remove(dca, NULL))
-			return (FALSE);
+			return (false);
 	} else {
 		if (!dircmp_rcs_scanfile_remove(dca, attr))
-			return (FALSE);
+			return (false);
 	}
 	attr->a_namelen = sv_namelen;
 	if (!dircmp_rcs_scanfile_add(dca, attr))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_scanfile_update(struct dircmp_args *dca, struct scanfile_attr *attr)
 {
 	struct cvsync_attr *cap = &dca->dca_attr;
@@ -728,16 +700,16 @@ dircmp_rcs_scanfile_update(struct dircmp_args *dca, struct scanfile_attr *attr)
 	size_t base, len;
 
 	if ((base = attr->a_namelen + 6) > dca->dca_cmdmax)
-		return (FALSE);
+		return (false);
 
 	switch (attr->a_type) {
 	case FILETYPE_DIR:
 		if (cap->ca_type != FILETYPE_DIR)
 			return (dircmp_rcs_scanfile_replace(dca, attr));
 		if (attr->a_auxlen != cap->ca_auxlen)
-			return (FALSE);
+			return (false);
 		if (memcmp(cap->ca_aux, attr->a_aux, attr->a_auxlen) == 0)
-			return (TRUE);
+			return (true);
 		cmd[2] = FILESCAN_SETATTR;
 		len = attr->a_auxlen;
 		break;
@@ -745,9 +717,9 @@ dircmp_rcs_scanfile_update(struct dircmp_args *dca, struct scanfile_attr *attr)
 		if (cap->ca_type != FILETYPE_FILE)
 			return (dircmp_rcs_scanfile_replace(dca, attr));
 		if (attr->a_auxlen != cap->ca_auxlen)
-			return (FALSE);
+			return (false);
 		if (memcmp(cap->ca_aux, attr->a_aux, attr->a_auxlen) == 0)
-			return (TRUE);
+			return (true);
 		if (GetDDWord(&((uint8_t *)attr->a_aux)[8]) == 0)
 			return (dircmp_rcs_scanfile_replace(dca, attr));
 		if (memcmp(cap->ca_aux, attr->a_aux, attr->a_auxlen - 2) == 0)
@@ -763,9 +735,9 @@ dircmp_rcs_scanfile_update(struct dircmp_args *dca, struct scanfile_attr *attr)
 			return (dircmp_rcs_scanfile_replace(dca, attr));
 		}
 		if (attr->a_auxlen != cap->ca_auxlen)
-			return (FALSE);
+			return (false);
 		if (memcmp(cap->ca_aux, attr->a_aux, attr->a_auxlen) == 0)
-			return (TRUE);
+			return (true);
 		if (cap->ca_type != attr->a_type) {
 			cmd[2] = FILESCAN_RCS_ATTIC;
 		} else {
@@ -783,35 +755,35 @@ dircmp_rcs_scanfile_update(struct dircmp_args *dca, struct scanfile_attr *attr)
 			return (dircmp_rcs_scanfile_replace(dca, attr));
 		if ((attr->a_auxlen == cap->ca_auxlen) &&
 		    (memcmp(cap->ca_aux, attr->a_aux, attr->a_auxlen) == 0)) {
-			return (TRUE);
+			return (true);
 		}
 		cmd[2] = FILESCAN_UPDATE;
 		len = 0;
 		break;
 	default:
-		return (FALSE);
+		return (false);
 	}
 
 	SetWord(cmd, len + base - 2);
 	cmd[3] = attr->a_type;
 	SetWord(&cmd[4], attr->a_namelen);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(dca->dca_mux, MUX_FILESCAN, attr->a_name,
 		      attr->a_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 	if (len > 0) {
 		if (!mux_send(dca->dca_mux, MUX_FILESCAN, attr->a_aux,
 			      attr->a_auxlen)) {
-			return (FALSE);
+			return (false);
 		}
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_rcs_scanfile_read(struct dircmp_args *dca, struct scanfile_attr *attr)
 {
 	struct collection *cl = dca->dca_collection;
@@ -820,21 +792,21 @@ dircmp_rcs_scanfile_read(struct dircmp_args *dca, struct scanfile_attr *attr)
 	char *name;
 
 	if (sa->sa_start == sa->sa_end)
-		return (FALSE);
+		return (false);
 
 	rpref_attr.a_name = cl->cl_rprefix;
 	rpref_attr.a_namelen = cl->cl_rprefixlen + 1;
 
 	for (;;) {
 		if (!scanfile_read_attr(sa->sa_start, sa->sa_end, attr))
-			return (FALSE);
+			return (false);
 
 		if (cl->cl_rprefixlen == 0) {
 			if (dircmp_access_scanfile(dca, attr))
 				break;
 			sa->sa_start += attr->a_size;
 			if (sa->sa_start == sa->sa_end)
-				return (FALSE);
+				return (false);
 			continue;
 		}
 
@@ -842,14 +814,14 @@ dircmp_rcs_scanfile_read(struct dircmp_args *dca, struct scanfile_attr *attr)
 			if (!dircmp_isparent(attr, &rpref_attr)) {
 				sa->sa_start += attr->a_size;
 				if (sa->sa_start == sa->sa_end)
-					return (FALSE);
+					return (false);
 				continue;
 			}
 			if (dircmp_access_scanfile(dca, attr))
 				break;
 			sa->sa_start += attr->a_size;
 			if (sa->sa_start == sa->sa_end)
-				return (FALSE);
+				return (false);
 			continue;
 		}
 
@@ -860,32 +832,32 @@ dircmp_rcs_scanfile_read(struct dircmp_args *dca, struct scanfile_attr *attr)
 				break;
 			sa->sa_start += attr->a_size;
 			if (sa->sa_start == sa->sa_end)
-				return (FALSE);
+				return (false);
 			continue;
 		}
 
 		sa->sa_start += attr->a_size;
 		if (sa->sa_start == sa->sa_end)
-			return (FALSE);
+			return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 dircmp_isparent(struct scanfile_attr *dirattr, struct scanfile_attr *attr)
 {
 	if (dirattr == NULL)
-		return (TRUE);
+		return (true);
 	if (dirattr->a_type != FILETYPE_DIR)
-		return (FALSE);
+		return (false);
 
 	if (dirattr->a_namelen >= attr->a_namelen)
-		return (FALSE);
+		return (false);
 	if (((char *)attr->a_name)[dirattr->a_namelen] != '/')
-		return (FALSE);
+		return (false);
 	if (memcmp(dirattr->a_name, attr->a_name, dirattr->a_namelen) != 0)
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
