@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,8 +36,15 @@
 #include <string.h>
 #include <unistd.h>
 
+#include "compat_stdbool.h"
+#include "compat_stdint.h"
+#include "compat_inttypes.h"
+#include "compat_limits.h"
+#include "basedef.h"
+
 #include "attribute.h"
 #include "cvsync.h"
+#include "cvsync_attr.h"
 #include "filetypes.h"
 #include "hash.h"
 #include "logmsg.h"
@@ -49,38 +56,39 @@
 #include "filescan.h"
 #include "filecmp.h"
 
-boolean filescan_rcs_fetch(struct filescan_args *);
+bool filescan_rcs_fetch(struct filescan_args *);
 
-boolean filescan_rcs_add(struct filescan_args *);
-boolean filescan_rcs_remove(struct filescan_args *);
-boolean filescan_rcs_attic(struct filescan_args *);
-boolean filescan_rcs_setattr(struct filescan_args *);
-boolean filescan_rcs_setattr_dir(struct filescan_args *);
-boolean filescan_rcs_setattr_file(struct filescan_args *);
-boolean filescan_rcs_update(struct filescan_args *);
+bool filescan_rcs_add(struct filescan_args *);
+bool filescan_rcs_remove(struct filescan_args *);
+bool filescan_rcs_attic(struct filescan_args *);
+bool filescan_rcs_setattr(struct filescan_args *);
+bool filescan_rcs_setattr_dir(struct filescan_args *);
+bool filescan_rcs_setattr_file(struct filescan_args *);
+bool filescan_rcs_update(struct filescan_args *);
 
-boolean filescan_rcs_update_rcs(struct filescan_args *, struct cvsync_file *);
-boolean filescan_rcs_update_rcs_admin(struct filescan_args *,
-				      struct rcslib_file *);
-boolean filescan_rcs_update_rcs_delta(struct filescan_args *,
-				      struct rcslib_file *);
-boolean filescan_rcs_update_rcs_deltatext(struct filescan_args *,
-					  struct rcslib_file *);
-boolean filescan_rcs_update_symlink(struct filescan_args *);
+bool filescan_rcs_update_rcs(struct filescan_args *, struct cvsync_file *);
+bool filescan_rcs_update_rcs_admin(struct filescan_args *,
+				   struct rcslib_file *);
+bool filescan_rcs_update_rcs_delta(struct filescan_args *,
+				   struct rcslib_file *);
+bool filescan_rcs_update_rcs_deltatext(struct filescan_args *,
+				       struct rcslib_file *);
+bool filescan_rcs_update_symlink(struct filescan_args *);
+bool filescan_rcs_replace(struct filescan_args *);
 
 static const uint8_t _cmde[3] = { 0x00, 0x01, FILECMP_UPDATE_END };
 
-boolean
+bool
 filescan_rcs(struct filescan_args *fsa)
 {
 	struct cvsync_attr *cap = &fsa->fsa_attr;
 
 	for (;;) {
 		if (cvsync_isinterrupted())
-			return (FALSE);
+			return (false);
 
 		if (!filescan_rcs_fetch(fsa))
-			return (FALSE);
+			return (false);
 
 		if (cap->ca_tag == FILESCAN_END)
 			break;
@@ -93,46 +101,46 @@ filescan_rcs(struct filescan_args *fsa)
 			if (!filescan_rcs_add(fsa)) {
 				logmsg_err("FileScan(RCS): ADD %s",
 					   fsa->fsa_path);
-				return (FALSE);
+				return (false);
 			}
 			break;
 		case FILESCAN_REMOVE:
 			if (!filescan_rcs_remove(fsa)) {
 				logmsg_err("FileScan(RCS): REMOVE %s",
 					   fsa->fsa_path);
-				return (FALSE);
+				return (false);
 			}
 			break;
 		case FILESCAN_RCS_ATTIC:
 			if (!filescan_rcs_attic(fsa)) {
 				logmsg_err("FileScan(RCS): ATTIC %s",
 					   fsa->fsa_path);
-				return (FALSE);
+				return (false);
 			}
 			break;
 		case FILESCAN_SETATTR:
 			if (!filescan_rcs_setattr(fsa)) {
 				logmsg_err("FileScan(RCS): SETATTR %s",
 					   fsa->fsa_path);
-				return (FALSE);
+				return (false);
 			}
 			break;
 		case FILESCAN_UPDATE:
 			if (!filescan_rcs_update(fsa)) {
 				logmsg_err("FileScan(RCS): UPDATE %s",
 					   fsa->fsa_path);
-				return (FALSE);
+				return (false);
 			}
 			break;
 		default:
-			return (FALSE);
+			return (false);
 		}
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_fetch(struct filescan_args *fsa)
 {
 	struct cvsync_attr *cap = &fsa->fsa_attr;
@@ -140,61 +148,61 @@ filescan_rcs_fetch(struct filescan_args *fsa)
 	size_t pathlen, len;
 
 	if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN, cmd, 3))
-		return (FALSE);
+		return (false);
 	len = GetWord(cmd);
 	if ((len == 0) || (len > fsa->fsa_cmdmax - 2))
-		return (FALSE);
+		return (false);
 	if ((cap->ca_tag = cmd[2]) == FILESCAN_END)
 		return (len == 1);
 	if (len < 2)
-		return (FALSE);
+		return (false);
 
 	if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN, cmd, 3))
-		return (FALSE);
+		return (false);
 
 	cap->ca_type = cmd[0];
 	if ((cap->ca_namelen = GetWord(&cmd[1])) > sizeof(cap->ca_name))
-		return (FALSE);
+		return (false);
 
 	switch (cap->ca_tag) {
 	case FILESCAN_ADD:
 	case FILESCAN_REMOVE:
 		if (cap->ca_namelen != len - 4)
-			return (FALSE);
+			return (false);
 		if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN, cap->ca_name,
 			      cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		break;
 	case FILESCAN_RCS_ATTIC:
 		if ((cap->ca_type != FILETYPE_RCS) &&
 		    (cap->ca_type != FILETYPE_RCS_ATTIC)) {
-			return (FALSE);
+			return (false);
 		}
 		if (cap->ca_namelen != len - RCS_ATTRLEN_RCS - 4)
-			return (FALSE);
+			return (false);
 		if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN, cap->ca_name,
 			      cap->ca_namelen)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!IS_FILE_RCS(cap->ca_name, cap->ca_namelen))
-			return (FALSE);
+			return (false);
 		if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN, cmd,
 			      RCS_ATTRLEN_RCS)) {
-			return (FALSE);
+			return (false);
 		}
 		if (!attr_rcs_decode_rcs(cmd, RCS_ATTRLEN_RCS, cap))
-			return (FALSE);
+			return (false);
 		break;
 	case FILESCAN_UPDATE:
 		if (cap->ca_type == FILETYPE_DIR)
-			return (FALSE);
+			return (false);
 		if (cap->ca_type == FILETYPE_SYMLINK) {
 			if (len != cap->ca_namelen + 4)
-				return (FALSE);
+				return (false);
 			if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN,
 				      cap->ca_name, cap->ca_namelen)) {
-				return (FALSE);
+				return (false);
 			}
 			break;
 		}
@@ -203,76 +211,76 @@ filescan_rcs_fetch(struct filescan_args *fsa)
 		switch (cap->ca_type) {
 		case FILETYPE_DIR:
 			if (cap->ca_namelen != len - RCS_ATTRLEN_DIR - 4)
-				return (FALSE);
+				return (false);
 			if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN,
 				      cap->ca_name, cap->ca_namelen)) {
-				return (FALSE);
+				return (false);
 			}
 			if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN, cmd,
 				      RCS_ATTRLEN_DIR)) {
-				return (FALSE);
+				return (false);
 			}
 			if (!attr_rcs_decode_dir(cmd, RCS_ATTRLEN_DIR, cap))
-				return (FALSE);
+				return (false);
 			break;
 		case FILETYPE_FILE:
 			if (cap->ca_namelen != len - RCS_ATTRLEN_FILE - 4)
-				return (FALSE);
+				return (false);
 			if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN,
 				      cap->ca_name, cap->ca_namelen)) {
-				return (FALSE);
+				return (false);
 			}
 			if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN, cmd,
 				      RCS_ATTRLEN_FILE)) {
-				return (FALSE);
+				return (false);
 			}
 			if (!attr_rcs_decode_file(cmd, RCS_ATTRLEN_FILE, cap))
-				return (FALSE);
+				return (false);
 			break;
 		case FILETYPE_RCS:
 		case FILETYPE_RCS_ATTIC:
 			if (cap->ca_namelen != len - RCS_ATTRLEN_RCS - 4)
-				return (FALSE);
+				return (false);
 			if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN,
 				      cap->ca_name, cap->ca_namelen)) {
-				return (FALSE);
+				return (false);
 			}
 			if (!IS_FILE_RCS(cap->ca_name, cap->ca_namelen))
-				return (FALSE);
+				return (false);
 			if (!mux_recv(fsa->fsa_mux, MUX_FILESCAN_IN, cmd,
 				      RCS_ATTRLEN_RCS)) {
-				return (FALSE);
+				return (false);
 			}
 			if (!attr_rcs_decode_rcs(cmd, RCS_ATTRLEN_RCS, cap))
-				return (FALSE);
+				return (false);
 			break;
 		default:
-			return (FALSE);
+			return (false);
 		}
 		break;
 	default:
-		return (FALSE);
+		return (false);
 	}
 
 	if (!cvsync_rcs_pathname((char *)cap->ca_name, cap->ca_namelen))
-		return (FALSE);
+		return (false);
 
 	if ((pathlen = fsa->fsa_pathlen + cap->ca_namelen) >= fsa->fsa_pathmax)
-		return (FALSE);
+		return (false);
 
 	memcpy(fsa->fsa_rpath, cap->ca_name, cap->ca_namelen);
 	fsa->fsa_rpath[cap->ca_namelen] = '\0';
 	if (cap->ca_type == FILETYPE_RCS_ATTIC) {
 		if (!cvsync_rcs_insert_attic(fsa->fsa_path, pathlen,
 					     fsa->fsa_pathmax)) {
-			return (FALSE);
+			return (false);
 		}
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_add(struct filescan_args *fsa)
 {
 	struct cvsync_attr *cap = &fsa->fsa_attr;
@@ -280,23 +288,23 @@ filescan_rcs_add(struct filescan_args *fsa)
 	size_t len;
 
 	if ((len = cap->ca_namelen + 6) > fsa->fsa_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILECMP_ADD;
 	cmd[3] = cap->ca_type;
 	SetWord(&cmd[4], cap->ca_namelen);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cap->ca_name,
 		      cap->ca_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_remove(struct filescan_args *fsa)
 {
 	struct cvsync_attr *cap = &fsa->fsa_attr;
@@ -304,23 +312,23 @@ filescan_rcs_remove(struct filescan_args *fsa)
 	size_t len;
 
 	if ((len = cap->ca_namelen + 6) > fsa->fsa_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILECMP_REMOVE;
 	cmd[3] = cap->ca_type;
 	SetWord(&cmd[4], cap->ca_namelen);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cap->ca_name,
 		      cap->ca_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_attic(struct filescan_args *fsa)
 {
 	struct cvsync_file *cfp;
@@ -334,29 +342,48 @@ filescan_rcs_attic(struct filescan_args *fsa)
 		pathlen = fsa->fsa_pathlen + cap->ca_namelen;
 		if (!cvsync_rcs_insert_attic(fsa->fsa_path, pathlen,
 					     fsa->fsa_pathmax)) {
-			return (FALSE);
+			return (false);
 		}
 		break;
 	case FILETYPE_RCS_ATTIC:
 		pathlen = fsa->fsa_pathlen + cap->ca_namelen + 6;
 		if (!cvsync_rcs_remove_attic(fsa->fsa_path, pathlen))
-			return (FALSE);
+			return (false);
 		break;
 	default:
-		return (FALSE);
+		return (false);
 	}
 
-	if ((cfp = cvsync_fopen(fsa->fsa_path)) == NULL)
-		return (FALSE);
+	if ((cfp = cvsync_fopen(fsa->fsa_path)) == NULL) {
+		switch (cap->ca_type) {
+		case FILETYPE_RCS:
+			pathlen = fsa->fsa_pathlen + cap->ca_namelen + 6;
+			if (!cvsync_rcs_remove_attic(fsa->fsa_path, pathlen))
+				return (false);
+			break;
+		case FILETYPE_RCS_ATTIC:
+			pathlen = fsa->fsa_pathlen + cap->ca_namelen;
+			if (!cvsync_rcs_insert_attic(fsa->fsa_path, pathlen,
+						     fsa->fsa_pathmax)) {
+				return (false);
+			}
+			break;
+		default:
+			return (false);
+		}
+		if (!filescan_rcs_remove(fsa))
+			return (false);
+		return (filescan_rcs_add(fsa));
+	}
 	if (!cvsync_mmap(cfp, 0, cfp->cf_size)) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 	mode = RCS_MODE(cfp->cf_mode, fsa->fsa_umask);
 
 	if ((base = cap->ca_namelen + 6) > fsa->fsa_cmdmax) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 
 	cmd[2] = FILECMP_RCS_ATTIC;
@@ -365,21 +392,21 @@ filescan_rcs_attic(struct filescan_args *fsa)
 	if ((len = attr_rcs_encode_rcs(&cmd[6], fsa->fsa_cmdmax - base,
 				       cfp->cf_mtime, mode)) == 0) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 	SetWord(cmd, len + base - 2);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 6)) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cap->ca_name,
 		      cap->ca_namelen)) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, &cmd[6], len)) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 
 	switch (cap->ca_type) {
@@ -387,12 +414,12 @@ filescan_rcs_attic(struct filescan_args *fsa)
 		if (fsa->fsa_proto < CVSYNC_PROTO(0, 24)) {
 			if (!filescan_generic_update(fsa, cfp)) {
 				cvsync_fclose(cfp);
-				return (FALSE);
+				return (false);
 			}
 		} else {
 			if (!filescan_rdiff_update(fsa, cfp)) {
 				cvsync_fclose(cfp);
-				return (FALSE);
+				return (false);
 			}
 		}
 		break;
@@ -400,21 +427,21 @@ filescan_rcs_attic(struct filescan_args *fsa)
 	case FILETYPE_RCS_ATTIC:
 		if (!filescan_rcs_update_rcs(fsa, cfp)) {
 			cvsync_fclose(cfp);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	default:
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 
 	if (!cvsync_fclose(cfp))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_setattr(struct filescan_args *fsa)
 {
 	switch (fsa->fsa_attr.ca_type) {
@@ -428,10 +455,10 @@ filescan_rcs_setattr(struct filescan_args *fsa)
 		break;
 	}
 
-	return (FALSE);
+	return (false);
 }
 
-boolean
+bool
 filescan_rcs_setattr_dir(struct filescan_args *fsa)
 {
 	struct cvsync_attr *cap = &fsa->fsa_attr;
@@ -442,21 +469,21 @@ filescan_rcs_setattr_dir(struct filescan_args *fsa)
 
 	if (lstat(fsa->fsa_path, &st) == -1) {
 		if (errno != ENOENT)
-			return (FALSE);
+			return (false);
 		st.st_mode = S_IFDIR;
 	}
 	if (!S_ISDIR(st.st_mode))
 		return (filescan_rcs_remove(fsa));
 
 	if ((mode = RCS_MODE(st.st_mode, fsa->fsa_umask)) == cap->ca_mode)
-		return (TRUE);
+		return (true);
 
 	if ((base = cap->ca_namelen + 6) > fsa->fsa_cmdmax)
-		return (FALSE);
+		return (false);
 
 	if ((len = attr_rcs_encode_dir(&cmd[6], fsa->fsa_cmdmax - base,
 				       mode)) == 0) {
-		return (FALSE);
+		return (false);
 	}
 
 	SetWord(cmd, len + base - 2);
@@ -464,18 +491,18 @@ filescan_rcs_setattr_dir(struct filescan_args *fsa)
 	cmd[3] = cap->ca_type;
 	SetWord(&cmd[4], cap->ca_namelen);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cap->ca_name,
 		      cap->ca_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, &cmd[6], len))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_setattr_file(struct filescan_args *fsa)
 {
 	struct cvsync_attr *cap = &fsa->fsa_attr;
@@ -485,31 +512,31 @@ filescan_rcs_setattr_file(struct filescan_args *fsa)
 	size_t base, len;
 
 	if (lstat(fsa->fsa_path, &st) == -1)
-		return (filescan_rcs_add(fsa));
+		return (filescan_rcs_replace(fsa));
 
 	if ((mode = RCS_MODE(st.st_mode, fsa->fsa_umask)) == cap->ca_mode)
-		return (TRUE);
+		return (true);
 
 	if ((base = cap->ca_namelen + 6) > fsa->fsa_cmdmax)
-		return (FALSE);
+		return (false);
 	len = fsa->fsa_cmdmax - base;
 
 	switch (cap->ca_type) {
 	case FILETYPE_FILE:
 		if ((len = attr_rcs_encode_file(&cmd[6], len, st.st_mtime,
 						st.st_size, mode)) == 0) {
-			return (FALSE);
+			return (false);
 		}
 		break;
 	case FILETYPE_RCS:
 	case FILETYPE_RCS_ATTIC:
 		if ((len = attr_rcs_encode_rcs(&cmd[6], len, st.st_mtime,
 					       mode)) == 0) {
-			return (FALSE);
+			return (false);
 		}
 		break;
 	default:
-		return (FALSE);
+		return (false);
 	}
 
 	SetWord(cmd, len + base - 2);
@@ -517,18 +544,18 @@ filescan_rcs_setattr_file(struct filescan_args *fsa)
 	cmd[3] = cap->ca_type;
 	SetWord(&cmd[4], cap->ca_namelen);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cap->ca_name,
 		      cap->ca_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, &cmd[6], len))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_update(struct filescan_args *fsa)
 {
 	struct cvsync_file *cfp;
@@ -541,16 +568,16 @@ filescan_rcs_update(struct filescan_args *fsa)
 		return (filescan_rcs_update_symlink(fsa));
 
 	if ((cfp = cvsync_fopen(fsa->fsa_path)) == NULL)
-		return (FALSE);
+		return (filescan_rcs_replace(fsa));
 	if (!cvsync_mmap(cfp, 0, cfp->cf_size)) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 	mode = RCS_MODE(cfp->cf_mode, fsa->fsa_umask);
 
 	if ((base = cap->ca_namelen + 6) > fsa->fsa_cmdmax) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 	len = fsa->fsa_cmdmax - base;
 
@@ -559,7 +586,7 @@ filescan_rcs_update(struct filescan_args *fsa)
 		if ((len = attr_rcs_encode_file(&cmd[6], len, cfp->cf_mtime,
 						cfp->cf_size, mode)) == 0) {
 			cvsync_fclose(cfp);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	case FILETYPE_RCS:
@@ -567,7 +594,7 @@ filescan_rcs_update(struct filescan_args *fsa)
 		if ((len = attr_rcs_encode_rcs(&cmd[6], len, cfp->cf_mtime,
 					       mode)) == 0) {
 			cvsync_fclose(cfp);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	}
@@ -578,16 +605,16 @@ filescan_rcs_update(struct filescan_args *fsa)
 	SetWord(&cmd[4], cap->ca_namelen);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 6)) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cap->ca_name,
 		      cap->ca_namelen)) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, &cmd[6], len)) {
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 
 	switch (cap->ca_type) {
@@ -595,12 +622,12 @@ filescan_rcs_update(struct filescan_args *fsa)
 		if (fsa->fsa_proto < CVSYNC_PROTO(0, 24)) {
 			if (!filescan_generic_update(fsa, cfp)) {
 				cvsync_fclose(cfp);
-				return (FALSE);
+				return (false);
 			}
 		} else {
 			if (!filescan_rdiff_update(fsa, cfp)) {
 				cvsync_fclose(cfp);
-				return (FALSE);
+				return (false);
 			}
 		}
 		break;
@@ -608,21 +635,21 @@ filescan_rcs_update(struct filescan_args *fsa)
 	case FILETYPE_RCS_ATTIC:
 		if (!filescan_rcs_update_rcs(fsa, cfp)) {
 			cvsync_fclose(cfp);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	default:
 		cvsync_fclose(cfp);
-		return (FALSE);
+		return (false);
 	}
 
 	if (!cvsync_fclose(cfp))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_update_rcs(struct filescan_args *fsa, struct cvsync_file *cfp)
 {
 	static const uint8_t _cmds[3] = { 0x00, 0x01, FILECMP_UPDATE_RCS };
@@ -631,7 +658,7 @@ filescan_rcs_update_rcs(struct filescan_args *fsa, struct cvsync_file *cfp)
 
 	if ((cap->ca_type != FILETYPE_RCS) &&
 	    (cap->ca_type != FILETYPE_RCS_ATTIC)) {
-		return (FALSE);
+		return (false);
 	}
 
 	if ((rcs = rcslib_init(cfp->cf_addr, cfp->cf_size)) == NULL) {
@@ -648,31 +675,31 @@ filescan_rcs_update_rcs(struct filescan_args *fsa, struct cvsync_file *cfp)
 
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, _cmds, sizeof(_cmds))) {
 		rcslib_destroy(rcs);
-		return (FALSE);
+		return (false);
 	}
 
 	if (!filescan_rcs_update_rcs_admin(fsa, rcs)) {
 		rcslib_destroy(rcs);
-		return (FALSE);
+		return (false);
 	}
 	if (!filescan_rcs_update_rcs_delta(fsa, rcs)) {
 		rcslib_destroy(rcs);
-		return (FALSE);
+		return (false);
 	}
 	if (!filescan_rcs_update_rcs_deltatext(fsa, rcs)) {
 		rcslib_destroy(rcs);
-		return (FALSE);
+		return (false);
 	}
 
 	rcslib_destroy(rcs);
 
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, _cmde, sizeof(_cmde)))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_update_rcs_admin(struct filescan_args *fsa,
 			      struct rcslib_file *rcs)
 {
@@ -684,31 +711,31 @@ filescan_rcs_update_rcs_admin(struct filescan_args *fsa,
 
 	/* head */
 	if ((len = rcs->head.n_len + 4) > fsa->fsa_cmdmax)
-		return (FALSE);
+		return (false);
 	SetWord(cmd, len - 2);
 	cmd[2] = FILECMP_UPDATE_RCS_HEAD;
 	cmd[3] = rcs->head.n_len;
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-		return (FALSE);
+		return (false);
 	if (rcs->head.n_len > 0) {
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, rcs->head.n_str,
 			      rcs->head.n_len)) {
-			return (FALSE);
+			return (false);
 		}
 	}
 
 	/* branch */
 	if ((len = rcs->branch.n_len + 4) > fsa->fsa_cmdmax)
-		return (FALSE);
+		return (false);
 	SetWord(cmd, len - 2);
 	cmd[2] = FILECMP_UPDATE_RCS_BRANCH;
 	cmd[3] = rcs->branch.n_len;
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-		return (FALSE);
+		return (false);
 	if (rcs->branch.n_len > 0) {
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, rcs->branch.n_str,
 			      rcs->branch.n_len)) {
-			return (FALSE);
+			return (false);
 		}
 	}
 
@@ -717,23 +744,23 @@ filescan_rcs_update_rcs_admin(struct filescan_args *fsa,
 	cmd[2] = FILECMP_UPDATE_RCS_ACCESS;
 	cmd[3] = rcs->access.ra_count;
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-		return (FALSE);
+		return (false);
 	if (rcs->access.ra_count > 0) {
 		for (i = 0 ; i < rcs->access.ra_count ; i++) {
 			id = &rcs->access.ra_id[i];
 			if ((len = id->i_len + 1) > fsa->fsa_cmdmax)
-				return (FALSE);
+				return (false);
 			cmd[0] = id->i_len;
 			if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 1))
-				return (FALSE);
+				return (false);
 			if (!mux_send(fsa->fsa_mux, MUX_FILECMP, id->i_id,
 				      id->i_len)) {
-				return (FALSE);
+				return (false);
 			}
 		}
 	}
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, _cmde, sizeof(_cmde)))
-		return (FALSE);
+		return (false);
 
 	/* symbols */
 	if (fsa->fsa_proto < CVSYNC_PROTO(0, 24)) {
@@ -741,13 +768,13 @@ filescan_rcs_update_rcs_admin(struct filescan_args *fsa,
 		cmd[2] = FILECMP_UPDATE_RCS_SYMBOLS;
 		cmd[3] = rcs->symbols.rs_count;
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-			return (FALSE);
+			return (false);
 	} else {
 		SetWord(cmd, 5);
 		cmd[2] = FILECMP_UPDATE_RCS_SYMBOLS;
 		SetDWord(&cmd[3], rcs->symbols.rs_count);
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 7))
-			return (FALSE);
+			return (false);
 	}
 	if (rcs->symbols.rs_count > 0) {
 		for (i = 0 ; i < rcs->symbols.rs_count ; i++) {
@@ -759,23 +786,23 @@ filescan_rcs_update_rcs_admin(struct filescan_args *fsa,
 
 			len = num->n_len + sym->s_len + 2;
 			if (len > fsa->fsa_cmdmax)
-				return (FALSE);
+				return (false);
 			cmd[0] = sym->s_len;
 			cmd[1] = num->n_len;
 			if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 2))
-				return (FALSE);
+				return (false);
 			if (!mux_send(fsa->fsa_mux, MUX_FILECMP, sym->s_sym,
 				      sym->s_len)) {
-				return (FALSE);
+				return (false);
 			}
 			if (!mux_send(fsa->fsa_mux, MUX_FILECMP, num->n_str,
 				      num->n_len)) {
-				return (FALSE);
+				return (false);
 			}
 		}
 	}
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, _cmde, sizeof(_cmde)))
-		return (FALSE);
+		return (false);
 
 	/* locks */
 	SetWord(cmd, 3);
@@ -783,7 +810,7 @@ filescan_rcs_update_rcs_admin(struct filescan_args *fsa,
 	cmd[3] = (rcs->locks.rl_strict != 0) ? 1 : 0;
 	cmd[4] = rcs->locks.rl_count;
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 5))
-		return (FALSE);
+		return (false);
 	if (rcs->locks.rl_count > 0) {
 		for (i = 0 ; i < rcs->locks.rl_count ; i++) {
 			struct rcslib_lock *lock = &rcs->locks.rl_locks[i];
@@ -791,61 +818,61 @@ filescan_rcs_update_rcs_admin(struct filescan_args *fsa,
 			num = &lock->num;
 			len = id->i_len + num->n_len + 2;
 			if (len > fsa->fsa_cmdmax)
-				return (FALSE);
+				return (false);
 			cmd[0] = id->i_len;
 			cmd[1] = num->n_len;
 			if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 2))
-				return (FALSE);
+				return (false);
 			if (!mux_send(fsa->fsa_mux, MUX_FILECMP, id->i_id,
 				      id->i_len)) {
-				return (FALSE);
+				return (false);
 			}
 			if (!mux_send(fsa->fsa_mux, MUX_FILECMP, num->n_str,
 				      num->n_len)) {
-				return (FALSE);
+				return (false);
 			}
 		}
 	}
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, _cmde, sizeof(_cmde)))
-		return (FALSE);
+		return (false);
 
 	/* comment */
 	if ((len = rcs->comment.s_len + 4) > fsa->fsa_cmdmax)
-		return (FALSE);
+		return (false);
 	SetWord(cmd, len - 2);
 	cmd[2] = FILECMP_UPDATE_RCS_COMMENT;
 	cmd[3] = rcs->comment.s_len;
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-		return (FALSE);
+		return (false);
 	if (rcs->comment.s_len > 0) {
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, rcs->comment.s_str,
 			      rcs->comment.s_len)) {
-			return (FALSE);
+			return (false);
 		}
 	}
 
 	/* expand */
 	if ((len = rcs->expand.s_len + 4) > fsa->fsa_cmdmax)
-		return (FALSE);
+		return (false);
 	SetWord(cmd, len - 2);
 	cmd[2] = FILECMP_UPDATE_RCS_EXPAND;
 	cmd[3] = rcs->expand.s_len;
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-		return (FALSE);
+		return (false);
 	if (rcs->expand.s_len > 0) {
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, rcs->expand.s_str,
 			      rcs->expand.s_len)) {
-			return (FALSE);
+			return (false);
 		}
 	}
 
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, _cmde, sizeof(_cmde)))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_update_rcs_delta(struct filescan_args *fsa,
 			      struct rcslib_file *rcs)
 {
@@ -857,7 +884,7 @@ filescan_rcs_update_rcs_delta(struct filescan_args *fsa,
 
 	SetDWord(cmd, rcs->delta.rd_count);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-		return (FALSE);
+		return (false);
 
 	/* delta */
 	for (i = 0 ; i < rcs->delta.rd_count ; i++) {
@@ -865,21 +892,21 @@ filescan_rcs_update_rcs_delta(struct filescan_args *fsa,
 
 		len = rev->num.n_len + hashops->length + 4;
 		if (len > fsa->fsa_cmdmax)
-			return (FALSE);
+			return (false);
 
 		/* num */
 		SetWord(cmd, len - 2);
 		cmd[2] = FILECMP_UPDATE_RCS_DELTA;
 		cmd[3] = rev->num.n_len;
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-			return (FALSE);
+			return (false);
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, rev->num.n_str,
 			      rev->num.n_len)) {
-			return (FALSE);
+			return (false);
 		}
 
 		if (!(*hashops->init)(&fsa->fsa_hash_ctx))
-			return (FALSE);
+			return (false);
 
 		/* date */
 		(*hashops->update)(fsa->fsa_hash_ctx, rev->date.rd_num.n_str,
@@ -907,16 +934,16 @@ filescan_rcs_update_rcs_delta(struct filescan_args *fsa,
 		(*hashops->final)(fsa->fsa_hash_ctx, cmd);
 
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, hashops->length))
-			return (FALSE);
+			return (false);
 	}
 
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, _cmde, sizeof(_cmde)))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_update_rcs_deltatext(struct filescan_args *fsa,
 				  struct rcslib_file *rcs)
 {
@@ -927,7 +954,7 @@ filescan_rcs_update_rcs_deltatext(struct filescan_args *fsa,
 
 	SetDWord(cmd, rcs->delta.rd_count);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-		return (FALSE);
+		return (false);
 
 	/* deltatext */
 	for (i = 0 ; i < rcs->delta.rd_count ; i++) {
@@ -935,21 +962,21 @@ filescan_rcs_update_rcs_deltatext(struct filescan_args *fsa,
 
 		len = rev->num.n_len + hashops->length + 4;
 		if (len > fsa->fsa_cmdmax)
-			return (FALSE);
+			return (false);
 
 		/* num */
 		SetWord(cmd, len - 2);
 		cmd[2] = FILECMP_UPDATE_RCS_DELTATEXT;
 		cmd[3] = rev->num.n_len;
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 4))
-			return (FALSE);
+			return (false);
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, rev->num.n_str,
 			      rev->num.n_len)) {
-			return (FALSE);
+			return (false);
 		}
 
 		if (!(*hashops->init)(&fsa->fsa_hash_ctx))
-			return (FALSE);
+			return (false);
 
 		/* log */
 		if (rev->log.s_len > 0) {
@@ -965,16 +992,16 @@ filescan_rcs_update_rcs_deltatext(struct filescan_args *fsa,
 		(*hashops->final)(fsa->fsa_hash_ctx, cmd);
 
 		if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, hashops->length))
-			return (FALSE);
+			return (false);
 	}
 
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, _cmde, sizeof(_cmde)))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 filescan_rcs_update_symlink(struct filescan_args *fsa)
 {
 	struct cvsync_attr *cap = &fsa->fsa_attr;
@@ -982,18 +1009,92 @@ filescan_rcs_update_symlink(struct filescan_args *fsa)
 	size_t len;
 
 	if ((len = cap->ca_namelen + 6) >= fsa->fsa_cmdmax)
-		return (FALSE);
+		return (false);
 
 	SetWord(cmd, len - 2);
 	cmd[2] = FILECMP_UPDATE;
 	cmd[3] = FILETYPE_SYMLINK;
 	SetWord(&cmd[4], cap->ca_namelen);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cmd, 6))
-		return (FALSE);
+		return (false);
 	if (!mux_send(fsa->fsa_mux, MUX_FILECMP, cap->ca_name,
 		      cap->ca_namelen)) {
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
+}
+
+bool
+filescan_rcs_replace(struct filescan_args *fsa)
+{
+	struct cvsync_attr *cap = &fsa->fsa_attr;
+	struct stat st;
+	size_t pathlen;
+
+	if ((lstat(fsa->fsa_path, &st) != -1) || (errno != ENOENT))
+		return (false);
+
+	switch (cap->ca_type) {
+	case FILETYPE_FILE:
+		if (!filescan_rcs_remove(fsa))
+			return (false);
+		if (!filescan_rcs_add(fsa))
+			return (false);
+		break;
+	case FILETYPE_RCS:
+		pathlen = fsa->fsa_pathlen + cap->ca_namelen;
+		if (!cvsync_rcs_insert_attic(fsa->fsa_path, pathlen,
+					     fsa->fsa_pathmax)) {
+			return (false);
+		}
+		if (lstat(fsa->fsa_path, &st) == 0) {
+			pathlen += 6;
+			if (!cvsync_rcs_remove_attic(fsa->fsa_path, pathlen))
+				return (false);
+			if (!filescan_rcs_attic(fsa))
+				return (false);
+		} else {
+			if (errno != ENOENT)
+				return (false);
+			if (!filescan_rcs_remove(fsa))
+				return (false);
+			pathlen += 6;
+			if (!cvsync_rcs_remove_attic(fsa->fsa_path, pathlen))
+				return (false);
+			if (!filescan_rcs_add(fsa))
+				return (false);
+		}
+		break;
+	case FILETYPE_RCS_ATTIC:
+		pathlen = fsa->fsa_pathlen + cap->ca_namelen + 6;
+		if (!cvsync_rcs_remove_attic(fsa->fsa_path, pathlen))
+			return (false);
+		if (lstat(fsa->fsa_path, &st) == 0) {
+			pathlen -= 6;
+			if (!cvsync_rcs_insert_attic(fsa->fsa_path, pathlen,
+						     fsa->fsa_pathmax)) {
+				return (false);
+			}
+			if (!filescan_rcs_attic(fsa))
+				return (false);
+		} else {
+			if (errno != ENOENT)
+				return (false);
+			if (!filescan_rcs_remove(fsa))
+				return (false);
+			pathlen -= 6;
+			if (!cvsync_rcs_insert_attic(fsa->fsa_path, pathlen,
+						     fsa->fsa_pathmax)) {
+				return (false);
+			}
+			if (!filescan_rcs_add(fsa))
+				return (false);
+		}
+		break;
+	default:
+		return (false);
+	}
+
+	return (true);
 }
