@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,15 +35,20 @@
 #include <errno.h>
 #include <limits.h>
 #include <pthread.h>
-#include <sched.h>
 #include <string.h>
 
+#include "compat_stdbool.h"
+#include "compat_stdint.h"
+#include "compat_inttypes.h"
+#include "compat_limits.h"
+#include "basedef.h"
+
 #include "cvsync.h"
 #include "logmsg.h"
 #include "mux.h"
 #include "network.h"
 
-boolean mux_reset(struct mux *, struct muxbuf *, uint8_t);
+bool mux_reset(struct mux *, struct muxbuf *, uint8_t);
 
 struct mux *
 mux_init(int sock, uint16_t mss, int compression, int level)
@@ -97,7 +102,7 @@ mux_init(int sock, uint16_t mss, int compression, int level)
 	for (i = 0 ; i < 2 ; i++) {
 		for (j = 0 ; j < MUX_MAXCHANNELS ; j++) {
 			mx->mx_buffer[i][j].mxb_state = MUX_STATE_INIT;
-			mx->mx_state[i][j] = FALSE;
+			mx->mx_state[i][j] = false;
 		}
 	}
 
@@ -110,7 +115,7 @@ mux_init(int sock, uint16_t mss, int compression, int level)
 	}
 
 	mx->mx_socket = sock;
-	mx->mx_isconnected = TRUE;
+	mx->mx_isconnected = true;
 	mx->mx_xfer_in = mx->mx_xfer_out = 0;
 
 	return (mx);
@@ -156,7 +161,7 @@ mux_abort(struct mux *mx)
 	}
 
 	shutdown(mx->mx_socket, SHUT_RDWR);
-	mx->mx_isconnected = FALSE;
+	mx->mx_isconnected = false;
 
 	pthread_mutex_unlock(&mx->mx_lock);
 
@@ -173,12 +178,9 @@ mux_abort(struct mux *mx)
 
 	if ((err = pthread_cond_broadcast(&mx->mx_wait)) != 0)
 		logmsg_err("Mux Error: cond broadcast: %s", strerror(err));
-
-	if (sched_yield() == -1)
-		logmsg_err("Mux Error: yield: %s", strerror(errno));
 }
 
-boolean
+bool
 muxbuf_init(struct muxbuf *mxb, uint16_t mss, uint32_t bufsize,
 	    int compression)
 {
@@ -187,41 +189,41 @@ muxbuf_init(struct muxbuf *mxb, uint16_t mss, uint32_t bufsize,
 	if (compression == CVSYNC_COMPRESS_NO) {
 		if ((mss < MUX_MIN_MSS) || (mss > MUX_MAX_MSS)) {
 			logmsg_err("MuxBuffer Error: invalid mss: %u", mss);
-			return (FALSE);
+			return (false);
 		}
 	} else {
 		if ((mss < MUX_MIN_MSS) || (mss > MUX_MAX_MSS_ZLIB)) {
 			logmsg_err("MuxBuffer Error: invalid mss: %u", mss);
-			return (FALSE);
+			return (false);
 		}
 	}
 	if ((bufsize < MUX_MIN_BUFSIZE) || (bufsize > MUX_MAX_BUFSIZE)) {
 		logmsg_err("MuxBuffer Error: invalid size: %u", bufsize);
-		return (FALSE);
+		return (false);
 	}
 
 	mxb->mxb_bufsize = bufsize;
 	if ((mxb->mxb_buffer = malloc(mxb->mxb_bufsize)) == NULL) {
 		logmsg_err("%s", strerror(errno));
-		return (FALSE);
+		return (false);
 	}
 	if ((err = pthread_mutex_init(&mxb->mxb_lock, NULL)) != 0) {
 		logmsg_err("MuxBuffer Error: mutex init: %s", strerror(err));
 		free(mxb->mxb_buffer);
-		return (FALSE);
+		return (false);
 	}
 	if ((err = pthread_cond_init(&mxb->mxb_wait_in, NULL)) != 0) {
 		logmsg_err("MuxBuffer Error: cond init: %s", strerror(err));
 		pthread_mutex_destroy(&mxb->mxb_lock);
 		free(mxb->mxb_buffer);
-		return (FALSE);
+		return (false);
 	}
 	if ((err = pthread_cond_init(&mxb->mxb_wait_out, NULL)) != 0) {
 		logmsg_err("MuxBuffer Error: cond init: %s", strerror(err));
 		pthread_cond_destroy(&mxb->mxb_wait_in);
 		pthread_mutex_destroy(&mxb->mxb_lock);
 		free(mxb->mxb_buffer);
-		return (FALSE);
+		return (false);
 	}
 
 	mxb->mxb_length = 0;
@@ -235,7 +237,7 @@ muxbuf_init(struct muxbuf *mxb, uint16_t mss, uint32_t bufsize,
 	else
 		mxb->mxb_size = mxb->mxb_mss / 2;
 
-	return (TRUE);
+	return (true);
 }
 
 void
@@ -251,9 +253,6 @@ muxbuf_destroy(struct muxbuf *mxb)
 	if ((err = pthread_mutex_unlock(&mxb->mxb_lock)) != 0)
 		logmsg_err("MuxBuffer Error: mutex init: %s", strerror(err));
 
-	if (sched_yield() == -1)
-		logmsg_err("MuxBuffer Error: yield: %s", strerror(errno));
-
 	if ((err = pthread_cond_destroy(&mxb->mxb_wait_out)) != 0) {
 		logmsg_err("MuxBuffer Error: cond(out) destroy: %s",
 			   strerror(err));
@@ -266,7 +265,7 @@ muxbuf_destroy(struct muxbuf *mxb)
 	free(mxb->mxb_buffer);
 }
 
-boolean
+bool
 mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 {
 	struct muxbuf *mxb = &mx->mx_buffer[MUX_OUT][chnum];
@@ -276,13 +275,13 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 
 	if ((err = pthread_mutex_lock(&mxb->mxb_lock)) != 0) {
 		logmsg_err("Mux(SEND) Error: mutex lock: %s", strerror(err));
-		return (FALSE);
+		return (false);
 	}
 	if (mxb->mxb_state != MUX_STATE_RUNNING) {
 		logmsg_err("Mux(SEND) Error: not running: %u", chnum);
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (mxb->mxb_length + bufsize < mxb->mxb_size) {
@@ -292,10 +291,10 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 		if ((err = pthread_mutex_unlock(&mxb->mxb_lock)) != 0) {
 			logmsg_err("Mux(SEND) Error: mutex unlock: %s",
 				   strerror(err));
-			return (FALSE);
+			return (false);
 		}
 
-		return (TRUE);
+		return (true);
 	}
 
 	while (mxb->mxb_rlength + mxb->mxb_size > mxb->mxb_bufsize) {
@@ -308,7 +307,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 				   strerror(err));
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 		logmsg_debug(DEBUG_BASE, "Mux(SEND): Wakeup(%u): %u, %u, %u",
 			     chnum, mxb->mxb_rlength, mxb->mxb_size,
@@ -317,7 +316,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 			logmsg_err("Mux(SEND) Error: not running: %u", chnum);
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 	}
 
@@ -327,14 +326,14 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 		logmsg_err("Mux(SEND) Error: mutex lock: %s", strerror(err));
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 	if (!mx->mx_isconnected) {
 		logmsg_err("Mux(SEND) Error: socket");
 		pthread_mutex_unlock(&mx->mx_lock);
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	switch (mx->mx_compress) {
@@ -343,7 +342,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 			pthread_mutex_unlock(&mx->mx_lock);
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	case CVSYNC_COMPRESS_ZLIB:
@@ -351,7 +350,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 			pthread_mutex_unlock(&mx->mx_lock);
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	default:
@@ -360,14 +359,14 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 		pthread_mutex_unlock(&mx->mx_lock);
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (pthread_mutex_unlock(&mx->mx_lock) != 0) {
 		logmsg_err("Mux(SEND) Error: mutex unlock: %s", strerror(err));
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	mxb->mxb_length = 0;
@@ -387,7 +386,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 					   strerror(err));
 				mxb->mxb_state = MUX_STATE_ERROR;
 				pthread_mutex_unlock(&mxb->mxb_lock);
-				return (FALSE);
+				return (false);
 			}
 			logmsg_debug(DEBUG_BASE, "Mux(SEND): Wakeup(%u): "
 				     "%u, %u, %u", chnum, mxb->mxb_rlength,
@@ -397,7 +396,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 					   chnum);
 				mxb->mxb_state = MUX_STATE_ERROR;
 				pthread_mutex_unlock(&mxb->mxb_lock);
-				return (FALSE);
+				return (false);
 			}
 		}
 
@@ -406,14 +405,14 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 				   strerror(err));
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 		if (!mx->mx_isconnected) {
 			logmsg_err("Mux(SEND) Error: socket");
 			pthread_mutex_unlock(&mx->mx_lock);
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 
 		switch (mx->mx_compress) {
@@ -422,7 +421,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 				pthread_mutex_unlock(&mx->mx_lock);
 				mxb->mxb_state = MUX_STATE_ERROR;
 				pthread_mutex_unlock(&mxb->mxb_lock);
-				return (FALSE);
+				return (false);
 			}
 			break;
 		case CVSYNC_COMPRESS_ZLIB:
@@ -430,7 +429,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 				pthread_mutex_unlock(&mx->mx_lock);
 				mxb->mxb_state = MUX_STATE_ERROR;
 				pthread_mutex_unlock(&mxb->mxb_lock);
-				return (FALSE);
+				return (false);
 			}
 			break;
 		default:
@@ -439,7 +438,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 			pthread_mutex_unlock(&mx->mx_lock);
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 
 		if ((err = pthread_mutex_unlock(&mx->mx_lock)) != 0) {
@@ -447,7 +446,7 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 				   strerror(err));
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 
 		sp += mxb->mxb_size;
@@ -462,13 +461,13 @@ mux_send(struct mux *mx, uint8_t chnum, const void *buffer, size_t bufsize)
 
 	if ((err = pthread_mutex_unlock(&mxb->mxb_lock)) != 0) {
 		logmsg_err("Mux(SEND) Error: mutex unlock: %s", strerror(err));
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 mux_recv(struct mux *mx, uint8_t chnum, void *buffer, size_t bufsize)
 {
 	struct muxbuf *mxb = &mx->mx_buffer[MUX_IN][chnum];
@@ -478,13 +477,13 @@ mux_recv(struct mux *mx, uint8_t chnum, void *buffer, size_t bufsize)
 
 	if ((err = pthread_mutex_lock(&mxb->mxb_lock)) != 0) {
 		logmsg_err("Mux(RECV) Error: mutex lock: %s", strerror(err));
-		return (FALSE);
+		return (false);
 	}
 	if (mxb->mxb_state != MUX_STATE_RUNNING) {
 		logmsg_err("Mux(RECV) Error: not running: %u", chnum);
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	while (bufsize > 0) {
@@ -496,7 +495,7 @@ mux_recv(struct mux *mx, uint8_t chnum, void *buffer, size_t bufsize)
 					   strerror(err));
 				mxb->mxb_state = MUX_STATE_ERROR;
 				pthread_mutex_unlock(&mxb->mxb_lock);
-				return (FALSE);
+				return (false);
 			}
 			logmsg_debug(DEBUG_BASE, "Mux(RECV): Wakeup(%u): %u",
 				     chnum, mxb->mxb_length);
@@ -505,7 +504,7 @@ mux_recv(struct mux *mx, uint8_t chnum, void *buffer, size_t bufsize)
 					   chnum);
 				mxb->mxb_state = MUX_STATE_ERROR;
 				pthread_mutex_unlock(&mxb->mxb_lock);
-				return (FALSE);
+				return (false);
 			}
 		}
 
@@ -535,7 +534,7 @@ mux_recv(struct mux *mx, uint8_t chnum, void *buffer, size_t bufsize)
 			if (!mux_reset(mx, mxb, chnum)) {
 				mxb->mxb_state = MUX_STATE_ERROR;
 				pthread_mutex_unlock(&mxb->mxb_lock);
-				return (FALSE);
+				return (false);
 			}
 		}
 
@@ -548,29 +547,29 @@ mux_recv(struct mux *mx, uint8_t chnum, void *buffer, size_t bufsize)
 		logmsg_err("Mux(RECV) Error: cond signal: %s", strerror(err));
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if ((err = pthread_mutex_unlock(&mxb->mxb_lock)) != 0) {
 		logmsg_err("Mux(RECV) Error: mutex unlock: %s", strerror(err));
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 mux_flush(struct mux *mx, uint8_t chnum)
 {
 	struct muxbuf *mxb = &mx->mx_buffer[MUX_OUT][chnum];
 
 	if (pthread_mutex_lock(&mxb->mxb_lock) != 0)
-		return (FALSE);
+		return (false);
 
 	if (mxb->mxb_state != MUX_STATE_RUNNING) {
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (mxb->mxb_length == 0)
@@ -581,25 +580,25 @@ mux_flush(struct mux *mx, uint8_t chnum)
 				      &mxb->mxb_lock) != 0) {
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 		if (mxb->mxb_state != MUX_STATE_RUNNING) {
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 	}
 
 	if (pthread_mutex_lock(&mx->mx_lock) != 0) {
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 	if (!mx->mx_isconnected) {
 		pthread_mutex_unlock(&mx->mx_lock);
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	switch (mx->mx_compress) {
@@ -608,7 +607,7 @@ mux_flush(struct mux *mx, uint8_t chnum)
 			pthread_mutex_unlock(&mx->mx_lock);
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	case CVSYNC_COMPRESS_ZLIB:
@@ -616,20 +615,20 @@ mux_flush(struct mux *mx, uint8_t chnum)
 			pthread_mutex_unlock(&mx->mx_lock);
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	default:
 		pthread_mutex_unlock(&mx->mx_lock);
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (pthread_mutex_unlock(&mx->mx_lock) != 0) {
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	mxb->mxb_rlength += mxb->mxb_length;
@@ -637,35 +636,35 @@ mux_flush(struct mux *mx, uint8_t chnum)
 
 done:
 	if (pthread_mutex_unlock(&mxb->mxb_lock) != 0)
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 mux_close_in(struct mux *mx, uint8_t chnum)
 {
 	struct muxbuf *mxb = &mx->mx_buffer[MUX_IN][chnum];
 	uint8_t cmd[MUX_CMDLEN_CLOSE];
 
 	if (pthread_mutex_lock(&mxb->mxb_lock) != 0)
-		return (FALSE);
+		return (false);
 
 	if (mxb->mxb_state != MUX_STATE_RUNNING) {
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 	if (mxb->mxb_length > 0) {
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if ((mxb->mxb_rlength > 0) && !mux_reset(mx, mxb, chnum)) {
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	mxb->mxb_state = MUX_STATE_CLOSED;
@@ -673,92 +672,92 @@ mux_close_in(struct mux *mx, uint8_t chnum)
 	if (pthread_cond_signal(&mxb->mxb_wait_in) != 0) {
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (pthread_mutex_unlock(&mxb->mxb_lock) != 0)
-		return (FALSE);
+		return (false);
 
 	cmd[0] = MUX_CMD_CLOSE;
 	cmd[1] = chnum;
 
 	if (pthread_mutex_lock(&mx->mx_lock) != 0)
-		return (FALSE);
+		return (false);
 	if (!mx->mx_isconnected) {
 		pthread_mutex_unlock(&mx->mx_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (!sock_send(mx->mx_socket, cmd, MUX_CMDLEN_CLOSE)) {
 		pthread_mutex_unlock(&mx->mx_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (pthread_mutex_unlock(&mx->mx_lock) != 0)
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 mux_close_out(struct mux *mx, uint8_t chnum)
 {
 	struct muxbuf *mxb = &mx->mx_buffer[MUX_OUT][chnum];
 
 	if (!mux_flush(mx, chnum))
-		return (FALSE);
+		return (false);
 
 	if (pthread_mutex_lock(&mxb->mxb_lock) != 0)
-		return (FALSE);
+		return (false);
 
 	while (mxb->mxb_state != MUX_STATE_CLOSED) {
 		if (pthread_cond_wait(&mxb->mxb_wait_in,
 				      &mxb->mxb_lock) != 0) {
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 		if ((mxb->mxb_state != MUX_STATE_RUNNING) &&
 		    (mxb->mxb_state != MUX_STATE_CLOSED)) {
 			mxb->mxb_state = MUX_STATE_ERROR;
 			pthread_mutex_unlock(&mxb->mxb_lock);
-			return (FALSE);
+			return (false);
 		}
 	}
 	if (mxb->mxb_rlength != 0) {
 		mxb->mxb_state = MUX_STATE_ERROR;
 		pthread_mutex_unlock(&mxb->mxb_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (pthread_mutex_unlock(&mxb->mxb_lock) != 0)
-		return (FALSE);
+		return (false);
 
 	if (pthread_mutex_lock(&mx->mx_lock) != 0)
-		return (FALSE);
+		return (false);
 	if (!mx->mx_isconnected) {
 		pthread_mutex_unlock(&mx->mx_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (mx->mx_state[MUX_OUT][chnum]) {
 		pthread_mutex_unlock(&mx->mx_lock);
-		return (FALSE);
+		return (false);
 	}
-	mx->mx_state[MUX_OUT][chnum] = TRUE;
+	mx->mx_state[MUX_OUT][chnum] = true;
 
 	if (pthread_cond_signal(&mx->mx_wait) != 0) {
 		pthread_mutex_unlock(&mx->mx_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (pthread_mutex_unlock(&mx->mx_lock) != 0)
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 mux_reset(struct mux *mx, struct muxbuf *mxb, uint8_t chnum)
 {
 	uint8_t cmd[MUX_CMDLEN_RESET];
@@ -770,29 +769,29 @@ mux_reset(struct mux *mx, struct muxbuf *mxb, uint8_t chnum)
 
 	if ((err = pthread_mutex_lock(&mx->mx_lock)) != 0) {
 		logmsg_err("Mux(RESET) Error: mutex lock: %s", strerror(err));
-		return (FALSE);
+		return (false);
 	}
 	if (!mx->mx_isconnected) {
 		logmsg_err("Mux(RESET) Error: socket");
 		pthread_mutex_unlock(&mx->mx_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if (!sock_send(mx->mx_socket, cmd, MUX_CMDLEN_RESET)) {
 		logmsg_err("Mux(RESET) Error: send");
 		pthread_mutex_unlock(&mx->mx_lock);
-		return (FALSE);
+		return (false);
 	}
 
 	if ((err = pthread_mutex_unlock(&mx->mx_lock)) != 0) {
 		logmsg_err("Mux(RESET) Error: mutex unlock: %s",
 			   strerror(err));
-		return (FALSE);
+		return (false);
 	}
 
 	logmsg_debug(DEBUG_BASE, "Mux(RESET) %u", chnum);
 
 	mxb->mxb_rlength = 0;
 
-	return (TRUE);
+	return (true);
 }
