@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,6 +37,8 @@
 #include <string.h>
 #include <time.h>
 
+#include "compat_stdbool.h"
+
 #include "rcslib.h"
 
 struct rcs_keyword {
@@ -102,7 +104,7 @@ enum {
 void rcslib_destroy_admin(struct rcslib_file *);
 void rcslib_destroy_delta(struct rcslib_file *);
 
-boolean rcslib_parse_rcstext(struct rcslib_file *, char *, const char *);
+bool rcslib_parse_rcstext(struct rcslib_file *, char *, const char *);
 
 char *rcslib_parse_admin(struct rcslib_file *, char *, const char *);
 char *rcslib_parse_delta(struct rcslib_file *, char *, const char *);
@@ -114,13 +116,15 @@ char *rcslib_parse_locks(char *, const char *, struct rcslib_locks *);
 char *rcslib_parse_date(char *, const char *, struct rcslib_date *);
 char *rcslib_parse_branches(char *, const char *, struct rcslib_branches *);
 char *rcslib_parse_newphrase(char *, const char *);
-char *rcslib_parse_word(char *, const char *);
 
+char *rcslib_parse_word(char *, const char *);
 char *rcslib_parse_num(char *, const char *, struct rcsnum *);
 char *rcslib_parse_id(char *, const char *, struct rcsid *);
 char *rcslib_parse_sym(char *, const char *, struct rcssym *);
 char *rcslib_parse_string(char *, const char *, struct rcsstr *);
 
+void rcslib_sort_revision(struct rcslib_file *);
+
 typedef int (*rcslib_cmp_func)(const void *, const void *);
 
 struct rcslib_file *
@@ -166,10 +170,10 @@ rcslib_destroy_admin(struct rcslib_file *rcs)
 void
 rcslib_destroy_delta(struct rcslib_file *rcs)
 {
-	if (rcs->delta.rd_count > 0) {
-		struct rcslib_revision *rev;
-		size_t i;
+	struct rcslib_revision *rev;
+	size_t i;
 
+	if (rcs->delta.rd_count > 0) {
 		for (i = 0 ; i < rcs->delta.rd_count ; i++) {
 			rev = &rcs->delta.rd_rev[i];
 			if (rev->branches.rb_num != NULL)
@@ -179,7 +183,7 @@ rcslib_destroy_delta(struct rcslib_file *rcs)
 	free(rcs->delta.rd_rev);
 }
 
-boolean
+bool
 rcslib_parse_rcstext(struct rcslib_file *rcs, char *sp, const char *bp)
 {
 	const struct rcs_keyword *rcskey = &rcs_keywords[RCS_DESC];
@@ -188,19 +192,21 @@ rcslib_parse_rcstext(struct rcslib_file *rcs, char *sp, const char *bp)
 	size_t i;
 
 	if ((sp = rcslib_parse_admin(rcs, sp, bp)) == NULL)
-		return (FALSE);
+		return (false);
 
 	if ((sp = rcslib_parse_delta(rcs, sp, bp)) == NULL) {
 		rcslib_destroy_admin(rcs);
-		return (FALSE);
+		return (false);
 	}
+	if (rcs->delta.rd_count > 0)
+		rcslib_sort_revision(rcs);
 
 	/* desc string */
 	if ((sp + rcskey->namelen > bp) ||
 	    (memcmp(sp, rcskey->name, rcskey->namelen) != 0)) {
 		rcslib_destroy_admin(rcs);
 		rcslib_destroy_delta(rcs);
-		return (FALSE);
+		return (false);
 	}
 	sp += rcskey->namelen;
 
@@ -209,33 +215,33 @@ rcslib_parse_rcstext(struct rcslib_file *rcs, char *sp, const char *bp)
 		if (++sp > bp) {
 			rcslib_destroy_admin(rcs);
 			rcslib_destroy_delta(rcs);
-			return (FALSE);
+			return (false);
 		}
 	}
 	if (sp == p) {
 		rcslib_destroy_admin(rcs);
 		rcslib_destroy_delta(rcs);
-		return (FALSE);
+		return (false);
 	}
 
 	if ((sp = rcslib_parse_string(sp, bp, &rcs->desc)) == NULL) {
 		rcslib_destroy_admin(rcs);
 		rcslib_destroy_delta(rcs);
-		return (FALSE);
+		return (false);
 	}
 
 	while (isspace((int)(*sp))) {
 		if (++sp > bp) {
 			rcslib_destroy_admin(rcs);
 			rcslib_destroy_delta(rcs);
-			return (FALSE);
+			return (false);
 		}
 	}
 
 	if ((sp = rcslib_parse_deltatext(rcs, sp, bp)) == NULL) {
 		rcslib_destroy_admin(rcs);
 		rcslib_destroy_delta(rcs);
-		return (FALSE);
+		return (false);
 	}
 
 	for (p = sp ; isspace((int)(*p)) ; p++) {
@@ -245,31 +251,37 @@ rcslib_parse_rcstext(struct rcslib_file *rcs, char *sp, const char *bp)
 	if (p != bp) {
 		rcslib_destroy_admin(rcs);
 		rcslib_destroy_delta(rcs);
-		return (FALSE);
+		return (false);
 	}
 
-	if (rcs->delta.rd_count > 0) {
-		for (i = 0 ; i < rcs->delta.rd_count ; i++) {
-			rev = &rcs->delta.rd_rev[i];
-			if (!(rev->flags & RCSLIB_REVISION_DELTATEXT)) {
-				rcslib_destroy_admin(rcs);
-				rcslib_destroy_delta(rcs);
-				return (FALSE);
-			}
-			if (rev->next.n_len == 0)
-				continue;
-			if (rcslib_lookup_revision(rcs, &rev->next) == NULL) {
-				rcslib_destroy_admin(rcs);
-				rcslib_destroy_delta(rcs);
-				return (FALSE);
-			}
+	if (rcs->delta.rd_count == 0)
+		return (true);
+
+	for (i = 0 ; i < rcs->delta.rd_count ; i++) {
+		rev = &rcs->delta.rd_rev[i];
+		if (!(rev->rv_flags & RCSLIB_REVISION_DELTATEXT)) {
+			rcslib_destroy_admin(rcs);
+			rcslib_destroy_delta(rcs);
+			return (false);
+		}
+		if (rev->next.n_len == 0)
+			continue;
+		if (i + 1 == rcs->delta.rd_count)
+			continue;
+		if (rcslib_cmp_num(&rcs->delta.rd_rev[i + 1].num,
+				   &rev->next) == 0) {
+			rev->rv_next = &rcs->delta.rd_rev[i + 1];
+			continue;
+		}
+		rev->rv_next = rcslib_lookup_revision(rcs, &rev->next);
+		if (rev->rv_next == NULL) {
+			rcslib_destroy_admin(rcs);
+			rcslib_destroy_delta(rcs);
+			return (false);
 		}
-
-		qsort(rcs->delta.rd_rev, rcs->delta.rd_count,
-		      RCSLIB_REVISION_SIZE, (rcslib_cmp_func)rcslib_cmp_num);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
 char *
@@ -391,7 +403,7 @@ rcslib_parse_delta(struct rcslib_file *rcs, char *sp, const char *bp)
 		if (delta->rd_count == delta->rd_size) {
 			size_t size = delta->rd_size, new;
 
-			new = (size == 0) ? 16 : size * 4;
+			new = (size == 0) ? 32 : size * 4;
 
 			rev = malloc(new * RCSLIB_REVISION_SIZE);
 			if (rev == NULL) {
@@ -646,7 +658,7 @@ rcslib_parse_deltatext(struct rcslib_file *rcs, char *sp, const char *bp)
 		if ((sp = rcslib_parse_string(sp, bp, &rev->text)) == NULL)
 			return (NULL);
 
-		rev->flags |= RCSLIB_REVISION_DELTATEXT;
+		rev->rv_flags |= RCSLIB_REVISION_DELTATEXT;
 
 		while (isspace((int)(*sp))) {
 			if (sp == bp)
@@ -760,7 +772,9 @@ rcslib_parse_symbols(char *sp, const char *bp, struct rcslib_symbols *symbols)
 
 	for (;;) {
 		if (symbols->rs_count == symbols->rs_size) {
-			size_t size = symbols->rs_size, new = size + 4;
+			size_t size = symbols->rs_size, new;
+
+			new = (size == 0) ? 32 : size * 4;
 
 			sym = malloc(new * RCSLIB_SYMBOL_SIZE);
 			if (sym == NULL) {
@@ -1305,17 +1319,17 @@ rcslib_parse_string(char *sp, const char *bp, struct rcsstr *str)
 
 	sv_sp = sp;
 
-	for (;;) {
-		while (*sp != '@') {
-			if (++sp > bp)
-				return (NULL);
+	while (sp < bp) {
+		if (*sp != '@') {
+			sp++;
+			continue;
 		}
 		if (*(sp + 1) != '@')
 			break;
-		else
-			sp++;
-		sp++;
+		sp += 2;
 	}
+	if (sp == bp)
+		return (NULL);
 
 	if (str != NULL) {
 		str->s_str = sv_sp;
@@ -1326,30 +1340,138 @@ rcslib_parse_string(char *sp, const char *bp, struct rcsstr *str)
 }
 
 struct rcslib_revision *
-rcslib_lookup_revision(struct rcslib_file *rcs, struct rcsnum *num)
+rcslib_lookup_revision(struct rcslib_file *rcs, const struct rcsnum *num)
 {
 	struct rcslib_delta *delta = &rcs->delta;
 	struct rcslib_revision *rev;
-	size_t i;
+	size_t l = 0, r = delta->rd_count, i;
+	int rv;
 
 	if ((delta->rd_count == 0) || (num->n_len == 0))
 		return (NULL);
 
-	for (i = 0 ; i < delta->rd_count ; i++) {
-		rev = &delta->rd_rev[i];
-		if ((num->n_len == rev->num.n_len) &&
-		    (memcmp(num->n_str, rev->num.n_str, num->n_len) == 0)) {
-			return (rev);
+	if (delta->rd_count < 100) {
+		for (i = 0 ; i < delta->rd_count ; i++) {
+			rev = &delta->rd_rev[i];
+			if ((num->n_len == rev->num.n_len) &&
+			    (memcmp(num->n_str, rev->num.n_str,
+				    num->n_len) == 0)) {
+				return (rev);
+			}
+		}
+	} else {
+		while (l <= r) {
+			i = (l + r) / 2;
+			rev = &delta->rd_rev[i];
+			if ((rv = rcslib_cmp_num(num, &rev->num)) == 0)
+				return (rev);
+			if (rv < 0) {
+				if (l == i)
+					break;
+				r = i - 1;
+			} else { /* rv > 0 */
+				if (r == i)
+					break;
+				l = i + 1;
+			}
 		}
 	}
 
 	return (NULL);
 }
 
-boolean
-rcslib_write_delta(int fd, struct rcslib_revision *rev)
+struct rcslib_revision *
+rcslib_lookup_symbol(struct rcslib_file *rcs, void *symstr, size_t symlen)
 {
-	struct rcslib_branches *branches = &rev->branches;
+	struct rcslib_revision *rev;
+	struct rcslib_symbol *symbol;
+	struct rcsnum *num = NULL, *br_num = NULL, t_num;
+	size_t sv_level, n, i;
+
+	for (i = 0 ; i < rcs->symbols.rs_count ; i++) {
+		symbol = &rcs->symbols.rs_symbols[i];
+		if ((symlen == symbol->sym.s_len) &&
+		    (memcmp(symstr, symbol->sym.s_sym, symlen) == 0)) {
+			num = &symbol->num;
+			break;
+		}
+	}
+	if (num == NULL) {
+		if (((symlen == 4) && (memcmp(symstr, "HEAD", 4) == 0)) ||
+		    ((symlen == 1) && (memcmp(symstr, ".", 1) == 0))) {
+			if (rcs->head.n_len != 0) {
+				rev = rcslib_lookup_revision(rcs, &rcs->head);
+			} else {
+				if (rcs->delta.rd_count == 0)
+					return (NULL);
+				rev = &rcs->delta.rd_rev[0];
+			}
+			if (rev == NULL)
+				return (NULL);
+			if (rcs->branch.n_len == 0)
+				return (rev);
+			num = &rcs->branch;
+		} else  {
+			if (!rcslib_str2num(symstr, symlen, &t_num))
+				return (NULL);
+			return (rcslib_lookup_revision(rcs, &t_num));
+		}
+	}
+
+	if ((num->n_level % 2) != 0) {
+		for (n = num->n_len - 1 ; n > 0 ; n--) {
+			if (num->n_str[n] == '.')
+				break;
+		}
+		if (n == 0)
+			return (NULL);
+		sv_level = num->n_level;
+	} else {
+		for (sv_level = 0 ; sv_level < num->n_level ; sv_level += 2) {
+			if (num->n_num[sv_level] == 0)
+				break;
+		}
+		if (sv_level == num->n_level)
+			return (rcslib_lookup_revision(rcs, num));
+
+		i = sv_level;
+		for (n = 0 ; n < num->n_len ; n++) {
+			if (num->n_str[n] == '.') {
+				if (--i == 0)
+					break;
+			}
+		}
+	}
+
+	if (!rcslib_str2num(num->n_str, n, &t_num))
+		return (NULL);
+	if ((rev = rcslib_lookup_revision(rcs, &t_num)) == NULL)
+		return (NULL);
+
+	for (n = 0 ; n < rev->branches.rb_count ; n++) {
+		br_num = &rev->branches.rb_num[n];
+		for (i = 0 ; i < sv_level ; i++) {
+			if (br_num->n_num[i] != num->n_num[i])
+				break;
+		}
+		if (i == sv_level)
+			break;
+	}
+	if (n == rev->branches.rb_count)
+		return (rev);
+
+	if ((rev = rcslib_lookup_revision(rcs, br_num)) == NULL)
+		return (NULL);
+	while (rev->rv_next != NULL)
+		rev = rev->rv_next;
+
+	return (rev);
+}
+
+bool
+rcslib_write_delta(int fd, const struct rcslib_revision *rev)
+{
+	const struct rcslib_branches *branches = &rev->branches;
 	struct iovec iov[8];
 	size_t i;
 	ssize_t wn;
@@ -1377,7 +1499,7 @@ rcslib_write_delta(int fd, struct rcslib_revision *rev)
 	     rev->state.i_len + iov[5].iov_len + 25;
 
 	if (writev(fd, iov, 8) != wn)
-		return (FALSE);
+		return (false);
 
 	iov[0].iov_base = "\n\t";
 	iov[0].iov_len = 2;
@@ -1385,7 +1507,7 @@ rcslib_write_delta(int fd, struct rcslib_revision *rev)
 		iov[1].iov_base = branches->rb_num[i].n_str;
 		iov[1].iov_len = branches->rb_num[i].n_len;
 		if (writev(fd, iov, 2) != branches->rb_num[i].n_len + 2)
-			return (FALSE);
+			return (false);
 	}
 
 	iov[0].iov_base =";\nnext\t";
@@ -1395,13 +1517,13 @@ rcslib_write_delta(int fd, struct rcslib_revision *rev)
 	iov[2].iov_base = ";\n\n";
 	iov[2].iov_len = 3;
 	if (writev(fd, iov, 3) != rev->next.n_len + 10)
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
-rcslib_write_deltatext(int fd, struct rcslib_revision *rev)
+bool
+rcslib_write_deltatext(int fd, const struct rcslib_revision *rev)
 {
 	struct iovec iov[7];
 	ssize_t wn;
@@ -1423,12 +1545,12 @@ rcslib_write_deltatext(int fd, struct rcslib_revision *rev)
 	wn = rev->num.n_len + rev->log.s_len + rev->text.s_len + 18;
 
 	if (writev(fd, iov, 7) != wn)
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 rcslib_str2num(void *buffer, size_t bufsize, struct rcsnum *num)
 {
 	char *sp = buffer;
@@ -1442,21 +1564,21 @@ rcslib_str2num(void *buffer, size_t bufsize, struct rcsnum *num)
 	for (i = 0 ; i < num->n_len ; i++) {
 		if (*sp == '.') {
 			if (num->n_level == RCSNUM_MAXLEVEL)
-				return (FALSE);
+				return (false);
 			num->n_num[++num->n_level] = 0;
 		} else if (isdigit((int)(*sp))) {
 			num->n_num[num->n_level] *= 10;
 			num->n_num[num->n_level] += *sp - '0';
 			if (num->n_num[num->n_level] > RCSNUM_MAX)
-				return (FALSE);
+				return (false);
 		} else {
-			return (FALSE);
+			return (false);
 		}
 		sp++;
 	}
 	num->n_level++;
 
-	return (TRUE);
+	return (true);
 }
 
 int
@@ -1554,3 +1676,51 @@ rcslib_cmp_sym(const struct rcssym *s1, const struct rcssym *s2)
 
 	return (rv);
 }
+
+bool
+rcslib_is_ancestor(const struct rcsnum *n1, const struct rcsnum *n2)
+{
+	size_t n, i;
+
+	if (n1->n_level > n2->n_level)
+		return (false);
+
+	n = n1->n_level - 1;
+
+	for (i = 0 ; i < n ; i++) {
+		if (n1->n_num[i] != n2->n_num[i])
+			return (false);
+	}
+
+	if (n1->n_level == 2) {
+		if (n1->n_num[n] < n2->n_num[n])
+			return (false);
+	} else {
+		if (n1->n_num[n] > n2->n_num[n])
+			return (false);
+	}
+
+	return (true);
+}
+
+void
+rcslib_sort_revision(struct rcslib_file *rcs)
+{
+	struct rcslib_revision *rev1, *rev2;
+	size_t n = rcs->delta.rd_count - 1, i;
+
+	for (i = 0 ; i < n ; i++) {
+		rev1 = &rcs->delta.rd_rev[i];
+		rev2 = &rcs->delta.rd_rev[i + 1];
+		if (rcslib_cmp_num(&rev1->num, &rev2->num) >= 0) {
+			break;
+		}
+	}
+	if (i == n) {
+		/* already sorted */
+		return;
+	}
+
+	qsort(rcs->delta.rd_rev, rcs->delta.rd_count, RCSLIB_REVISION_SIZE,
+	      (rcslib_cmp_func)rcslib_cmp_num);
+}
