@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,6 +41,13 @@
 #include <strings.h>
 #include <unistd.h>
 
+#include "compat_stdbool.h"
+#include "compat_stdint.h"
+#include "compat_stdio.h"
+#include "compat_inttypes.h"
+#include "compat_limits.h"
+#include "compat_strings.h"
+
 #include "attribute.h"
 #include "collection.h"
 #include "cvsync.h"
@@ -123,17 +130,17 @@ struct config *config_parse_file(struct config_args *);
 struct config *config_parse_file_config(struct config_args *);
 struct collection *config_parse_file_collection(struct config_args *);
 struct config *config_parse_uri(const char *, const char *);
-boolean config_parse_uri_host(const char *, const char *, struct config *);
-boolean config_parse_uri_collection(const char *, const char *,
-				    struct collection *);
-boolean config_parse_uri_aux(const char *, const char *, struct collection *);
+bool config_parse_uri_host(const char *, const char *, struct config *);
+bool config_parse_uri_collection(const char *, const char *,
+				 struct collection *);
+bool config_parse_uri_aux(const char *, const char *, struct collection *);
 
 struct config *config_init_config(void);
 struct collection *config_init_collection(void);
 
-boolean config_resolv_refuse(struct config *, struct collection *);
-boolean config_set_config_default(struct config *);
-boolean config_set_collection_default(struct config *, struct collection *);
+bool config_resolv_refuse(struct config *, struct collection *);
+bool config_set_config_default(struct config *);
+bool config_set_collection_default(struct config *, struct collection *);
 
 struct config *
 config_load_file(const char *cfname)
@@ -368,7 +375,7 @@ config_parse_file_config(struct config_args *ca)
 		if (cvsync_release_pton(cl->cl_release) == CVSYNC_RELEASE_LIST)
 			continue;
 
-		if (!config_resolv_prefix(cf, cl, FALSE /* rdwr */)) {
+		if (!config_resolv_prefix(cf, cl, false /* rdwr */)) {
 			config_destroy(cf);
 			return (NULL);
 		}
@@ -550,7 +557,7 @@ done:
 
 	switch (cvsync_release_pton(cl->cl_release)) {
 	case CVSYNC_RELEASE_RCS:
-		if (!config_resolv_prefix(cf, cl, TRUE /* rdwr */)) {
+		if (!config_resolv_prefix(cf, cl, true /* rdwr */)) {
 			config_destroy(cf);
 			collection_destroy(cl);
 			return (NULL);
@@ -579,7 +586,7 @@ done:
 	return (cf);
 }
 
-boolean
+bool
 config_parse_uri_host(const char *sp, const char *bp, struct config *cf)
 {
 	const char *sv_sp = sp, *ep;
@@ -588,20 +595,20 @@ config_parse_uri_host(const char *sp, const char *bp, struct config *cf)
 	if (*sp == '[') {
 		if (++sp >= bp) {
 			logmsg_err("host: premature EOL");
-			return (FALSE);
+			return (false);
 		}
 		if ((ep = memchr(sp, ']', bp - sp)) == NULL) {
 			logmsg_err("host: missing ']'");
-			return (FALSE);
+			return (false);
 		}
 		if ((len = ep - sp) >= sizeof(cf->cf_host)) {
 			logmsg_err("%.*s: host %.*s: %s", sv_len, sv_sp, len,
 				   sp, strerror(ENAMETOOLONG));
-			return (FALSE);
+			return (false);
 		}
 		if (len == 0) {
 			logmsg_err("host: empty string");
-			return (FALSE);
+			return (false);
 		}
 		memcpy(cf->cf_host, sp, len);
 		cf->cf_host[len] = '\0';
@@ -613,11 +620,11 @@ config_parse_uri_host(const char *sp, const char *bp, struct config *cf)
 		if ((len = ep - sp) >= sizeof(cf->cf_host)) {
 			logmsg_err("%.*s: host %.*s: %s", sv_len, sv_sp, len,
 				   sp, strerror(ENAMETOOLONG));
-			return (FALSE);
+			return (false);
 		}
 		if (len == 0) {
 			logmsg_err("host: empty string");
-			return (FALSE);
+			return (false);
 		}
 		memcpy(cf->cf_host, sp, len);
 		cf->cf_host[len] = '\0';
@@ -625,27 +632,27 @@ config_parse_uri_host(const char *sp, const char *bp, struct config *cf)
 		sp = ep;
 	}
 	if (sp >= bp)
-		return (TRUE);
+		return (true);
 
 	if (*sp++ != ':') {
 		logmsg_err("%.*s: port: %s", sv_len, sv_sp, strerror(EINVAL));
-		return (FALSE);
+		return (false);
 	}
 	if (sp >= bp)
-		return (TRUE);
+		return (true);
 
 	if ((len = bp - sp) >= sizeof(cf->cf_serv)) {
 		logmsg_err("%.*s: port %.*s: %s", sv_len, sv_sp, len, sp,
 			   strerror(ENAMETOOLONG));
-		return (FALSE);
+		return (false);
 	}
 	memcpy(cf->cf_serv, sp, len);
 	cf->cf_serv[len] = '\0';
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 config_parse_uri_collection(const char *sp, const char *bp,
 			    struct collection *cl)
 {
@@ -654,35 +661,35 @@ config_parse_uri_collection(const char *sp, const char *bp,
 
 	if ((ep = memchr(sp, '/', bp - sp)) == NULL) {
 		logmsg_err("name: premature EOL");
-		return (FALSE);
+		return (false);
 	}
 	if ((len = ep - sp) >= sizeof(cl->cl_name)) {
 		logmsg_err("name %.*s: %s", len, sp, strerror(ENAMETOOLONG));
-		return (FALSE);
+		return (false);
 	}
 	if (len == 0) {
 		logmsg_err("name: empty string");
-		return (FALSE);
+		return (false);
 	}
 	memcpy(cl->cl_name, sp, len);
 	cl->cl_name[len] = '\0';
 
 	if ((sp = ep + 1) >= bp) {
 		logmsg_err("release: premature EOL");
-		return (FALSE);
+		return (false);
 	}
 	if ((ep = memchr(sp, '/', bp - sp)) == NULL) {
 		logmsg_err("release: premature EOL");
-		return (FALSE);
+		return (false);
 	}
 	if ((len = ep - sp) >= sizeof(cl->cl_release)) {
 		logmsg_err("release %.*s: %s", len, sp,
 			   strerror(ENAMETOOLONG));
-		return (FALSE);
+		return (false);
 	}
 	if (len == 0) {
 		logmsg_err("release: empty string");
-		return (FALSE);
+		return (false);
 	}
 	memcpy(cl->cl_release, sp, len);
 	cl->cl_release[len] = '\0';
@@ -692,18 +699,18 @@ config_parse_uri_collection(const char *sp, const char *bp,
 	case CVSYNC_RELEASE_RCS:
 		if (++ep != bp) {
 			logmsg_err("%.*s: unknown extra data", bp - ep, ep);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	default:
 		logmsg_err("release %s: unknown release type", cl->cl_release);
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 config_parse_uri_aux(const char *sp, const char *bp, struct collection *cl)
 {
 	const struct token_keyword *key;
@@ -720,7 +727,7 @@ config_parse_uri_aux(const char *sp, const char *bp, struct collection *cl)
 		if (len == 0) {
 			logmsg_err("collection %s/%s: empty keyword",
 				   cl->cl_name, cl->cl_release);
-			return (FALSE);
+			return (false);
 		}
 
 		for (key = config_keywords ; key->name != NULL ; key++) {
@@ -732,7 +739,7 @@ config_parse_uri_aux(const char *sp, const char *bp, struct collection *cl)
 		if (key->name == NULL) {
 			logmsg_err("collection %s/%s: %.*s: unknown keyword",
 				   cl->cl_name, cl->cl_release, len, sp);
-			return (FALSE);
+			return (false);
 		}
 
 		switch (key->type) {
@@ -741,26 +748,26 @@ config_parse_uri_aux(const char *sp, const char *bp, struct collection *cl)
 				logmsg_err("collection %s/%s: %s: missing a "
 					   "separator '='", cl->cl_name,
 					   cl->cl_release, key->name);
-				return (FALSE);
+				return (false);
 			}
 			if ((sp = sep + 1) >= ep) {
 				logmsg_err("collection %s/%s: %s: empty",
 					   cl->cl_name, cl->cl_release,
 					   key->name);
-				return (FALSE);
+				return (false);
 			}
 			cl->cl_prefixlen = (size_t)(ep - sp);
 			if (cl->cl_prefixlen >= sizeof(cl->cl_prefix)) {
 				logmsg_err("collection %s/%s: %s: %s",
 					   cl->cl_name, cl->cl_release,
 					   key->name, strerror(ENAMETOOLONG));
-				return (FALSE);
+				return (false);
 			}
 			if (cl->cl_prefixlen == 0) {
 				logmsg_err("collection %s/%s: %s: empty "
 					   "string", cl->cl_name,
 					   cl->cl_release, key->name);
-				return (FALSE);
+				return (false);
 			}
 			memcpy(cl->cl_prefix, sp, cl->cl_prefixlen);
 			cl->cl_prefix[cl->cl_prefixlen] = '\0';
@@ -771,26 +778,26 @@ config_parse_uri_aux(const char *sp, const char *bp, struct collection *cl)
 				logmsg_err("collection %s/%s: %s: missing a "
 					   "separator '='", cl->cl_name,
 					   cl->cl_release, key->name);
-				return (FALSE);
+				return (false);
 			}
 			if ((sp = sep + 1) >= ep) {
 				logmsg_err("collection %s/%s: %s: empty",
 					   cl->cl_name, cl->cl_release,
 					   key->name);
-				return (FALSE);
+				return (false);
 			}
 			len = (size_t)(ep - sp);
 			if (len >= sizeof(cl->cl_scan_name)) {
 				logmsg_err("collection %s/%s: %s: %s",
 					   cl->cl_name, cl->cl_release,
 					   key->name, strerror(ENAMETOOLONG));
-				return (FALSE);
+				return (false);
 			}
 			if (len == 0) {
 				logmsg_err("collection %s/%s: %s: empty "
 					   "string", cl->cl_name,
 					   cl->cl_release, key->name);
-				return (FALSE);
+				return (false);
 			}
 			memcpy(cl->cl_scan_name, sp, len);
 			cl->cl_scan_name[len] = '\0';
@@ -799,13 +806,13 @@ config_parse_uri_aux(const char *sp, const char *bp, struct collection *cl)
 		default:
 			logmsg_err("collection %s/%s: %.*s: invalid keyword",
 				   cl->cl_name, cl->cl_release, len, sp);
-			return (FALSE);
+			return (false);
 		}
 
 		sp = ep + 1;
 	}
 
-	return (TRUE);
+	return (true);
 }
 
 struct config *
@@ -843,21 +850,21 @@ config_init_collection(void)
 	return (cl);
 }
 
-boolean
+bool
 config_resolv_refuse(struct config *cf, struct collection *cl)
 {
 	char path[PATH_MAX + CVSYNC_NAME_MAX + 1];
 	int wn;
 
 	if (strlen(cl->cl_refuse_name) == 0)
-		return (TRUE);
+		return (true);
 
 	if (cl->cl_refuse_name[0] != '/') {
 		if (strlen(cf->cf_base) == 0) {
 			logmsg_err("collection %s/%s: refuse %s: must be an "
 				   "absolute path", cl->cl_name,
 				   cl->cl_release, cl->cl_refuse_name);
-			return (FALSE);
+			return (false);
 		}
 		wn = snprintf(path, sizeof(path), "%s/%s", cf->cf_base,
 			      cl->cl_refuse_name);
@@ -868,16 +875,16 @@ config_resolv_refuse(struct config *cf, struct collection *cl)
 		logmsg_err("collection %s/%s: refuse %s: %s", cl->cl_name,
 			   cl->cl_release, cl->cl_refuse_name,
 			   strerror(EINVAL));
-		return (FALSE);
+		return (false);
 	}
 
 	if ((cl->cl_refuse = refuse_open(path)) == NULL)
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 config_set_config_default(struct config *cf)
 {
 	if (strlen(cf->cf_serv) == 0) {
@@ -891,18 +898,18 @@ config_set_config_default(struct config *cf)
 
 	if (strlen(cf->cf_host) == 0) {
 		logmsg_err("A remote host name is not specified");
-		return (FALSE);
+		return (false);
 	}
 	if (cf->cf_collections == NULL) {
 		logmsg_err("host %s port %s: no collections",
 			   cf->cf_host, cf->cf_serv);
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 config_set_collection_default(struct config *cf, struct collection *cl)
 {
 	struct collection *prev;
@@ -912,12 +919,12 @@ config_set_collection_default(struct config *cf, struct collection *cl)
 	case CVSYNC_RELEASE_LIST:
 		if (cf->cf_collections != NULL) {
 			logmsg_err("release 'list' is one only");
-			return (FALSE);
+			return (false);
 		}
 		if (cvsync_list_pton(cl->cl_name) == CVSYNC_LIST_UNKNOWN) {
 			logmsg_err("release 'list': %s: unknown name",
 				   cl->cl_name);
-			return (FALSE);
+			return (false);
 		}
 		break;
 	case CVSYNC_RELEASE_RCS:
@@ -930,14 +937,14 @@ config_set_collection_default(struct config *cf, struct collection *cl)
 			type = cvsync_release_pton(prev->cl_release);
 			if (type == CVSYNC_RELEASE_LIST) {
 				logmsg_err("release 'list' is one only");
-				return (FALSE);
+				return (false);
 			}
 		}
 		break;
 	default:
 		/* NOTREACHED */
-		return (FALSE);
+		return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
