@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
+ * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,6 +48,13 @@
 #include <string.h>
 #include <unistd.h>
 
+#include "compat_arpa_inet.h"
+#include "compat_stdbool.h"
+#include "compat_stdint.h"
+#include "compat_stdio.h"
+#include "compat_inttypes.h"
+#include "compat_limits.h"
+
 #include "cvsync.h"
 #include "list.h"
 #include "logmsg.h"
@@ -70,18 +77,18 @@ void access_close(struct access_control_args *);
 
 struct aclent *access_match(struct access_control_args *, int, const char *);
 struct access_control_args *access_parse(FILE *);
-boolean access_parse_allow(struct token *, struct aclent *);
-boolean access_parse_always(struct token *, struct aclent *);
-boolean access_parse_deny(struct token *, struct aclent *);
-boolean access_parse_address(char *, const char *, size_t, struct aclent *);
-boolean access_parse_hostname(char *, const char *, struct aclent *);
-boolean access_parse_number(char *, const char *, size_t *);
-boolean access_match_address(struct aclent *, int, const char *);
-boolean access_match_hostname(struct aclent *, const char *);
-boolean access_match_ipv4addr(struct aclent *, const void *);
-boolean access_match_ipv6addr(struct aclent *, const void *);
-boolean access_set_ipv4addr(struct aclent *, const void *, size_t);
-boolean access_set_ipv6addr(struct aclent *, const void *, size_t);
+bool access_parse_allow(struct token *, struct aclent *);
+bool access_parse_always(struct token *, struct aclent *);
+bool access_parse_deny(struct token *, struct aclent *);
+bool access_parse_address(char *, const char *, size_t, struct aclent *);
+bool access_parse_hostname(char *, const char *, struct aclent *);
+bool access_parse_number(char *, const char *, size_t *);
+bool access_match_address(struct aclent *, int, const char *);
+bool access_match_hostname(struct aclent *, const char *);
+bool access_match_ipv4addr(struct aclent *, const void *);
+bool access_match_ipv6addr(struct aclent *, const void *);
+bool access_set_ipv4addr(struct aclent *, const void *, size_t);
+bool access_set_ipv6addr(struct aclent *, const void *, size_t);
 
 static struct server_args **acl;
 static struct access_control_args *acl_lists;
@@ -93,7 +100,7 @@ static time_t acl_mtime = 0;
 static pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
 static pthread_mutex_t mtx = PTHREAD_MUTEX_INITIALIZER;
 
-boolean
+bool
 access_init(size_t sz)
 {
 #if !defined(NO_INITSTATE)
@@ -103,13 +110,13 @@ access_init(size_t sz)
 
 	if ((acl = malloc(sz * sizeof(*acl))) == NULL) {
 		logmsg_err("ACL: %s", strerror(errno));
-		return (FALSE);
+		return (false);
 	}
 	memset(acl, 0, sz * sizeof(*acl));
 
 	if ((acl_high = list_init()) == NULL) {
 		free(acl);
-		return (FALSE);
+		return (false);
 	}
 
 	gettimeofday(&tv, NULL);
@@ -124,7 +131,7 @@ access_init(size_t sz)
 	acl_name[0] = '\0';
 	acl_size = sz;
 
-	return (TRUE);
+	return (true);
 }
 
 void
@@ -364,7 +371,7 @@ access_open(const char *fname)
 	struct stat st;
 	FILE *fp;
 	int fd;
-	boolean force_load = FALSE;
+	bool force_load = false;
 
 	if (strlen(fname) == 0) {
 		access_close(acl_lists);
@@ -374,7 +381,7 @@ access_open(const char *fname)
 	}
 
 	if ((strlen(acl_name) == 0) || (strcmp(acl_name, fname) != 0))
-		force_load = TRUE;
+		force_load = true;
 
 	if ((fd = open(fname, O_RDONLY, 0)) == -1) {
 		if (errno != ENOENT) {
@@ -453,7 +460,7 @@ access_match(struct access_control_args *aca, int af, const char *addr)
 	struct aclent *aclp = NULL;
 	char host[CVSYNC_MAXHOST];
 	size_t i;
-	boolean resolved = FALSE;
+	bool resolved = false;
 
 	if ((aca == NULL) || (aca->aca_size == 0))
 		return (NULL);
@@ -464,7 +471,7 @@ access_match(struct access_control_args *aca, int af, const char *addr)
 		if (aclp->acl_family == AF_UNSPEC) {
 			if (!resolved) {
 				sock_resolv_addr(af, addr, host, sizeof(host));
-				resolved = TRUE;
+				resolved = true;
 			}
 			if (strlen(host) == 0)
 				continue;
@@ -581,7 +588,7 @@ access_parse(FILE *fp)
 	return (aca);
 }
 
-boolean
+bool
 access_parse_allow(struct token *tk, struct aclent *aclp)
 {
 	char *sp = tk->token, *bp = sp + tk->length, *sep;
@@ -589,27 +596,27 @@ access_parse_allow(struct token *tk, struct aclent *aclp)
 
 	if ((sep = memchr(sp, ',', bp - sp)) != NULL) {
 		if (sep + 1 >= bp)
-			return (FALSE);
+			return (false);
 		if (!access_parse_number(sep + 1, bp, &aclp->acl_max))
-			return (FALSE);
+			return (false);
 		bp = sep;
 	}
 
 	if ((sep = memchr(sp, '/', bp - sp)) != NULL) {
 		if (sep + 1 >= bp)
-			return (FALSE);
+			return (false);
 		if (!access_parse_number(sep + 1, bp, &n))
-			return (FALSE);
+			return (false);
 		return (access_parse_address(sp, sep, n, aclp));
 	}
 
 	if (!access_parse_address(sp, bp, (size_t)-1, aclp))
 		return (access_parse_hostname(sp, bp, aclp));
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 access_parse_always(struct token *tk, struct aclent *aclp)
 {
 	char *sp = tk->token, *bp = sp + tk->length, *sep;
@@ -617,19 +624,19 @@ access_parse_always(struct token *tk, struct aclent *aclp)
 
 	if ((sep = memchr(sp, '/', bp - sp)) != NULL) {
 		if (sep + 1 >= bp)
-			return (FALSE);
+			return (false);
 		if (!access_parse_number(sep + 1, bp, &n))
-			return (FALSE);
+			return (false);
 		return (access_parse_address(sp, sep, n, aclp));
 	}
 
 	if (!access_parse_address(sp, bp, (size_t)-1, aclp))
 		return (access_parse_hostname(sp, bp, aclp));
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 access_parse_deny(struct token *tk, struct aclent *aclp)
 {
 	char *sp = tk->token, *bp = sp + tk->length, *sep;
@@ -637,26 +644,26 @@ access_parse_deny(struct token *tk, struct aclent *aclp)
 
 	if ((sep = memchr(sp, '/', bp - sp)) != NULL) {
 		if (sep + 1 >= bp)
-			return (FALSE);
+			return (false);
 		if (!access_parse_number(sep + 1, bp, &n))
-			return (FALSE);
+			return (false);
 		return (access_parse_address(sp, sep, n, aclp));
 	}
 
 	if (!access_parse_address(sp, bp, (size_t)-1, aclp))
 		return (access_parse_hostname(sp, bp, aclp));
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 access_parse_address(char *sp, const char *bp, size_t n, struct aclent *aclp)
 {
 	char addr[CVSYNC_MAXHOST], binaddr[CVSYNC_MAXADDRLEN];
 	size_t addrlen;
 
 	if ((addrlen = bp - sp) >= sizeof(addr))
-		return (FALSE);
+		return (false);
 	memcpy(addr, sp, addrlen);
 	addr[addrlen] = '\0';
 
@@ -671,31 +678,31 @@ access_parse_address(char *sp, const char *bp, size_t n, struct aclent *aclp)
 	}
 #endif /* defined(AF_INET6) */
 
-	return (FALSE);
+	return (false);
 }
 
-boolean
+bool
 access_parse_hostname(char *sp, const char *bp, struct aclent *aclp)
 {
 	if (isdigit((int)(sp[bp - sp - 1])) ||
 	    (memchr(sp, ':', bp - sp) != NULL)) {
-		return (FALSE);
+		return (false);
 	}
 
 	aclp->acl_family = AF_UNSPEC;
 	aclp->acl_addrlen = bp - sp;
 	if ((aclp->acl_addr = malloc(aclp->acl_addrlen + 1)) == NULL) {
 		logmsg_err("ACL: %s", strerror(errno));
-		return (FALSE);
+		return (false);
 	}
 	memcpy(aclp->acl_addr, sp, aclp->acl_addrlen);
 	((char *)aclp->acl_addr)[aclp->acl_addrlen] = '\0';
 	aclp->acl_mask = NULL;
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 access_parse_number(char *sp, const char *bp, size_t *n)
 {
 	char s[5], *ep;
@@ -704,7 +711,7 @@ access_parse_number(char *sp, const char *bp, size_t *n)
 
 	if ((len = bp - sp) >= sizeof(s)) {
 		logmsg_err("ACL: %.*s: restricted to 1000", len, sp);
-		return (FALSE);
+		return (false);
 	}
 	memcpy(s, sp, len);
 	s[len] = '\0';
@@ -714,28 +721,28 @@ access_parse_number(char *sp, const char *bp, size_t *n)
 	if ((ep == NULL) || (*ep != '\0') || ((v == 0) && (errno == EINVAL)) ||
 	    ((v == ULONG_MAX) && (errno == ERANGE))) {
 		logmsg_err("ACL: %s: %s", s, strerror(EINVAL));
-		return (FALSE);
+		return (false);
 	}
 	if (v > 1000) {
 		logmsg_err("ACL: %lu: restricted to 1000", v);
-		return (FALSE);
+		return (false);
 	}
 
 	*n = (size_t)v;
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 access_match_address(struct aclent *aclp, int af, const char *addr)
 {
 	uint8_t binaddr[CVSYNC_MAXADDRLEN];
 
 	if (af != aclp->acl_family)
-		return (FALSE);
+		return (false);
 
 	if (inet_pton(af, addr, binaddr) != 1)
-		return (FALSE);
+		return (false);
 
 	switch (af) {
 	case AF_INET:
@@ -748,19 +755,19 @@ access_match_address(struct aclent *aclp, int af, const char *addr)
 		break;
 	}
 
-	return (FALSE);
+	return (false);
 }
 
-boolean
+bool
 access_match_hostname(struct aclent *aclp, const char *host)
 {
 	if (fnmatch(aclp->acl_addr, host, 0) == FNM_NOMATCH)
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 access_match_ipv4addr(struct aclent *aclp, const void *addr)
 {
 	uint32_t v4pat = *(uint32_t *)aclp->acl_addr;
@@ -768,12 +775,12 @@ access_match_ipv4addr(struct aclent *aclp, const void *addr)
 	uint32_t v4addr = *(uint32_t *)addr;
 
 	if (v4pat != (v4addr & v4mask))
-		return (FALSE);
+		return (false);
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 access_match_ipv6addr(struct aclent *aclp, const void *addr)
 {
 	const uint8_t *v6addr = addr;
@@ -782,13 +789,13 @@ access_match_ipv6addr(struct aclent *aclp, const void *addr)
 
 	for (i = 0 ; i < aclp->acl_addrlen ; i++) {
 		if (v6pat[i] != (v6addr[i] & v6mask[i]))
-			return (FALSE);
+			return (false);
 	}
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 access_set_ipv4addr(struct aclent *aclp, const void *addr, size_t netmask)
 {
 	uint32_t v4addr = *(uint32_t *)addr, v4mask;
@@ -800,7 +807,7 @@ access_set_ipv4addr(struct aclent *aclp, const void *addr, size_t netmask)
 	if (netmask == (size_t)-1)
 		netmask = addrbits;
 	if (netmask > addrbits)
-		return (FALSE);
+		return (false);
 	v4mask = ntohl(INADDR_BROADCAST);
 	if ((n = addrbits - netmask) > 0) {
 		v4mask >>= n;
@@ -810,20 +817,20 @@ access_set_ipv4addr(struct aclent *aclp, const void *addr, size_t netmask)
 
 	if ((aclp->acl_addr = malloc(aclp->acl_addrlen)) == NULL) {
 		logmsg_err("ACL: %s", strerror(errno));
-		return (FALSE);
+		return (false);
 	}
 	if ((aclp->acl_mask = malloc(aclp->acl_addrlen)) == NULL) {
 		logmsg_err("ACL: %s", strerror(errno));
 		free(aclp->acl_addr);
-		return (FALSE);
+		return (false);
 	}
 	*(uint32_t *)aclp->acl_addr = v4addr & v4mask;
 	*(uint32_t *)aclp->acl_mask = v4mask;
 
-	return (TRUE);
+	return (true);
 }
 
-boolean
+bool
 access_set_ipv6addr(struct aclent *aclp, const void *addr, size_t prefixlen)
 {
 	const uint8_t *v6addr = addr;
@@ -836,7 +843,7 @@ access_set_ipv6addr(struct aclent *aclp, const void *addr, size_t prefixlen)
 	if (prefixlen == (size_t)-1)
 		prefixlen = addrbits;
 	if (prefixlen > addrbits)
-		return (FALSE);
+		return (false);
 
 	n = prefixlen / 8;
 	for (i = 0 ; i < n ; i++)
@@ -852,17 +859,17 @@ access_set_ipv6addr(struct aclent *aclp, const void *addr, size_t prefixlen)
 
 	if ((aclp->acl_addr = malloc(aclp->acl_addrlen)) == NULL) {
 		logmsg_err("ACL: %s", strerror(errno));
-		return (FALSE);
+		return (false);
 	}
 	if ((aclp->acl_mask = malloc(aclp->acl_addrlen)) == NULL) {
 		logmsg_err("ACL: %s", strerror(errno));
 		free(aclp->acl_addr);
-		return (FALSE);
+		return (false);
 	}
 
 	for (i = 0 ; i < aclp->acl_addrlen ; i++)
 		((uint8_t *)aclp->acl_addr)[i] = v6addr[i] & v6mask[i];
 	memcpy(aclp->acl_mask, v6mask, aclp->acl_addrlen);
 
-	return (TRUE);
+	return (true);
 }
